Index: /trunk/psLib/src/astro/psCoord.c
===================================================================
--- /trunk/psLib/src/astro/psCoord.c	(revision 8244)
+++ /trunk/psLib/src/astro/psCoord.c	(revision 8245)
@@ -10,6 +10,6 @@
 *  @author GLG, MHPCC
 *
-*  @version $Revision: 1.122 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2006-08-08 23:32:22 $
+*  @version $Revision: 1.123 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2006-08-09 02:26:44 $
 *
 *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -589,12 +589,12 @@
     psPolynomial2D *trans2)
 {
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
-    psTrace(__func__, 5, "multiplyDPoly2D(%d %d: %d %d)\n", trans1->nX, trans1->nY, trans2->nX, trans2->nY);
+    psTrace("psLib.astro", 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.astro", 5, "multiplyDPoly2D(%d %d: %d %d)\n", trans1->nX, trans1->nY, trans2->nX, trans2->nY);
     psS32 orderX = trans1->nX + trans2->nX;
     psS32 orderY = trans1->nY + trans2->nY;
-    psTrace(__func__, 5, "out poly (nX, nY) is (%d, %d)\n", orderX, orderY);
+    psTrace("psLib.astro", 5, "out poly (nX, nY) is (%d, %d)\n", orderX, orderY);
 
     psPolynomial2D *out = psPolynomial2DAlloc(PS_POLYNOMIAL_ORD, orderX, orderY);
-    psTrace(__func__, 5, "Creating poly (%d, %d)\n", orderX, orderY);
+    psTrace("psLib.astro", 5, "Creating poly (%d, %d)\n", orderX, orderY);
 
     for (psS32 t1x = 0 ; t1x < (1 + trans1->nX) ; t1x++) {
@@ -609,5 +609,5 @@
         }
     }
-    psTrace(__func__, 4, "---- %s() end ----\n", __func__);
+    psTrace("psLib.astro", 4, "---- %s() end ----\n", __func__);
     return(out);
 }
@@ -623,13 +623,13 @@
     int nSamples)
 {
-    psTrace(__func__, 3, "---- %s() begin ----\n", __func__);
-    psTrace(__func__, 3, "tracelevel(%s) is %d\n", __func__, psTraceGetLevel(__func__));
+    psTrace("psLib.astro", 3, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.astro", 3, "tracelevel(%s) is %d\n", __func__, psTraceGetLevel(__func__));
 
     PS_ASSERT_PTR_NON_NULL(trans1, NULL);
     PS_ASSERT_PTR_NON_NULL(trans2, NULL);
-    psTrace(__func__, 5, "trans1->x is (%d, %d) order.\n", trans1->x->nX, trans1->x->nY);
-    psTrace(__func__, 5, "trans1->y is (%d, %d) order.\n", trans1->y->nX, trans1->y->nY);
-    psTrace(__func__, 5, "trans2->x is (%d, %d) order.\n", trans2->x->nX, trans2->x->nY);
-    psTrace(__func__, 5, "trans2->y is (%d, %d) order.\n", trans2->y->nX, trans2->y->nY);
+    psTrace("psLib.astro", 5, "trans1->x is (%d, %d) order.\n", trans1->x->nX, trans1->x->nY);
+    psTrace("psLib.astro", 5, "trans1->y is (%d, %d) order.\n", trans1->y->nX, trans1->y->nY);
+    psTrace("psLib.astro", 5, "trans2->x is (%d, %d) order.\n", trans2->x->nX, trans2->x->nY);
+    psTrace("psLib.astro", 5, "trans2->y is (%d, %d) order.\n", trans2->y->nX, trans2->y->nY);
     if (psTraceGetLevel(__func__) >= 6) {
         PS_POLY_PRINT_2D(trans1->x);
@@ -648,5 +648,5 @@
     psS32 orderX = PS_MAX(orderXnX, orderYnX);
     psS32 orderY = PS_MAX(orderXnY, orderYnY);
-    psTrace(__func__, 5, "The new (orderX, orderY) is (%d, %d)\n", orderX, orderY);
+    psTrace("psLib.astro", 5, "The new (orderX, orderY) is (%d, %d)\n", orderX, orderY);
 
     //
@@ -679,5 +679,5 @@
         }
     }
-    psTrace(__func__, 5, "New polynomial ranks are (%d %d %d %d)\n", myPT->x->nX, myPT->x->nY, myPT->y->nX, myPT->y->nY);
+    psTrace("psLib.astro", 5, "New polynomial ranks are (%d %d %d %d)\n", myPT->x->nX, myPT->x->nY, myPT->y->nX, myPT->y->nY);
 
     //
@@ -707,10 +707,10 @@
     }
 
-    psTrace(__func__, 5, "Determine the new x-polynomial\n");
+    psTrace("psLib.astro", 5, "Determine the new x-polynomial\n");
     for (psS32 t2x = 0 ; t2x < (trans2->x->nX + 1) ; t2x++) {
         for (psS32 t2y = 0 ; t2y < (trans2->x->nY + 1) ; t2y++) {
-            psTrace(__func__, 6, "X: -------------------- (t2x, t2y) (%d, %d) --------------------\n", t2x, t2y);
+            psTrace("psLib.astro", 6, "X: -------------------- (t2x, t2y) (%d, %d) --------------------\n", t2x, t2y);
             if (trans2->x->mask[t2x][t2y] == 0) {
-                psTrace(__func__, 6, "In this iteration, we raise trans1->x to the %d power and trans1->y to the %d-power.\n", t2x, t2y);
+                psTrace("psLib.astro", 6, "In this iteration, we raise trans1->x to the %d power and trans1->y to the %d-power.\n", t2x, t2y);
                 psPolynomial2D *newPoly = multiplyDPoly2D(trans1XPolys[t2x], trans1YPolys[t2y]);
 
@@ -734,5 +734,5 @@
     }
     if (psTraceGetLevel(__func__) >= 6) {
-        psTrace(__func__, 6, "The final x-polynomial\n");
+        psTrace("psLib.astro", 6, "The final x-polynomial\n");
         PS_POLY_PRINT_2D(myPT->x);
     }
@@ -741,10 +741,10 @@
     // Determine the new y-polynomial
     //
-    psTrace(__func__, 5, "Determine the new y-polynomial\n");
+    psTrace("psLib.astro", 5, "Determine the new y-polynomial\n");
     for (psS32 t2x = 0 ; t2x < (trans2->y->nX + 1) ; t2x++) {
         for (psS32 t2y = 0 ; t2y < (trans2->y->nY + 1) ; t2y++) {
-            psTrace(__func__, 5, "Y: -------------------- (t2x, t2y) (%d, %d) --------------------\n", t2x, t2y);
+            psTrace("psLib.astro", 5, "Y: -------------------- (t2x, t2y) (%d, %d) --------------------\n", t2x, t2y);
             if (trans2->y->mask[t2x][t2y] == 0) {
-                psTrace(__func__, 5, "In this iteration, we raise trans1->x to the %d power and trans1->y to the %d-power.\n", t2x, t2y);
+                psTrace("psLib.astro", 5, "In this iteration, we raise trans1->x to the %d power and trans1->y to the %d-power.\n", t2x, t2y);
                 psPolynomial2D *newPoly = multiplyDPoly2D(trans1XPolys[t2x], trans1YPolys[t2y]);
 
@@ -767,5 +767,5 @@
     }
     if (psTraceGetLevel(__func__) >= 6) {
-        psTrace(__func__, 6, "The final y-polynomial\n");
+        psTrace("psLib.astro", 6, "The final y-polynomial\n");
         PS_POLY_PRINT_2D(myPT->y);
     }
@@ -778,5 +778,5 @@
     psFree(trans1YPolys);
 
-    psTrace(__func__, 3, "---- %s() end ----\n", __func__);
+    psTrace("psLib.astro", 3, "---- %s() end ----\n", __func__);
     return(myPT);
 }
@@ -969,5 +969,5 @@
 
             out->x+= xPoly->coeff[loop_x][loop_y] * xSum * ySum * ((psF32) loop_x);
-            psTrace(__func__, 6, "out->x+= (%.2f * %.2f * %.2f * %.2f)\n", xPoly->coeff[loop_x][loop_y], xSum, ySum, ((psF32) loop_x));
+            psTrace("psLib.astro", 6, "out->x+= (%.2f * %.2f * %.2f * %.2f)\n", xPoly->coeff[loop_x][loop_y], xSum, ySum, ((psF32) loop_x));
             ySum*= coord->y;
         }
@@ -991,5 +991,5 @@
 
             out->y+= yPoly->coeff[loop_x][loop_y] * xSum * ySum * ((psF32) loop_y);
-            psTrace(__func__, 6, "out->y+= (%.2f * %.2f * %.2f * %.2f)\n", yPoly->coeff[loop_x][loop_y], xSum, ySum, ((psF32) loop_y));
+            psTrace("psLib.astro", 6, "out->y+= (%.2f * %.2f * %.2f * %.2f)\n", yPoly->coeff[loop_x][loop_y], xSum, ySum, ((psF32) loop_y));
             ySum*= coord->y;
         }
Index: /trunk/psLib/src/fits/psFitsTable.c
===================================================================
--- /trunk/psLib/src/fits/psFitsTable.c	(revision 8244)
+++ /trunk/psLib/src/fits/psFitsTable.c	(revision 8245)
@@ -7,6 +7,6 @@
  *  @author Robert DeSonia, MHPCC
  *
- *  @version $Revision: 1.19 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-08-08 23:32:23 $
+ *  @version $Revision: 1.20 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-08-09 02:26:44 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -74,5 +74,5 @@
     }
 
-    psTrace(".psFits.psFitsReadTableRow",5,"Table size is %ix%i\n",numCols, numRows);
+    psTrace("psLib.fits",5,"Table size is %ix%i\n",numCols, numRows);
     // the row parameter in the proper range?
     if (row < 0 || row >= numRows) {
@@ -110,5 +110,5 @@
                     fits_read_col(fits->fd, FITSTYPE, col,row+1, \
                                   1, 1, NULL, &value, &anynul, &status); \
-                    psTrace(".psFits.psFitsReadTableRow",5,"Column #%i, '%s', is type %i, repeat %i, Value = %g\n", \
+                    psTrace("psLib.fits",5,"Column #%i, '%s', is type %i, repeat %i, Value = %g\n", \
                             col, name, typecode, repeat, (double)value); \
                     psMetadataAdd(data,PS_LIST_TAIL, name, \
@@ -144,5 +144,5 @@
                     fits_read_col(fits->fd, TSTRING, col,row+1,
                                   1, 1, NULL, &value, &anynul, &status);
-                    psTrace(".psFits.psFitsReadTableRow",5,"Column #%i, '%s', is type %i, repeat %i, value = %s\n",
+                    psTrace("psLib.fits",5,"Column #%i, '%s', is type %i, repeat %i, value = %s\n",
                             col, name, typecode, repeat, value);
                     if (anynul == 0) {
@@ -158,5 +158,5 @@
                           typecode, col);
 
-                psTrace("psFits.psFitsReadTableRow", 2,
+                psTrace("psLib.fits", 2,
                         "Column %d or row %d was of a non primitive type, %d",
                         col, row, typecode);
@@ -387,5 +387,5 @@
 
     for (int row = 0; row < numRows; row++) {
-        psTrace(".psFits.psFitsReadTable",5,"Reading row %i of %i\n",row, numRows);
+        psTrace("psLib.fits",5,"Reading row %i of %i\n",row, numRows);
         table->data[row] = psFitsReadTableRow(fits,row);
         table->n++;
Index: /trunk/psLib/src/math/psMatrix.c
===================================================================
--- /trunk/psLib/src/math/psMatrix.c	(revision 8244)
+++ /trunk/psLib/src/math/psMatrix.c	(revision 8245)
@@ -21,6 +21,6 @@
  *  @author Robert DeSonia, MHPCC
  *
- *  @version $Revision: 1.41 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-08-08 23:32:23 $
+ *  @version $Revision: 1.42 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-08-09 02:26:44 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -343,5 +343,5 @@
                         if (ipiv[k] > 1) {
                             // psError(PS_ERR_BAD_PARAMETER_VALUE, true, "Singular Matrix (1).\n");
-                            psTrace(__func__, 4, "Singular Matrix (1).\n");
+                            psTrace("psLib.math", 4, "Singular Matrix (1).\n");
                             goto fescape;
                         }
Index: /trunk/psLib/src/math/psMinimizeLMM.c
===================================================================
--- /trunk/psLib/src/math/psMinimizeLMM.c	(revision 8244)
+++ /trunk/psLib/src/math/psMinimizeLMM.c	(revision 8245)
@@ -10,6 +10,6 @@
  *  @author EAM, IfA
  *
- *  @version $Revision: 1.18 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-07-15 02:57:12 $
+ *  @version $Revision: 1.19 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-08-09 02:26:44 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -71,5 +71,5 @@
 
     // LU decomposition version
-    psTrace(__func__, 5, "using LUD version\n");
+    psTrace("psLib.math", 5, "using LUD version\n");
 
     // set new guess values (creates matrix A)
@@ -103,5 +103,5 @@
     # else
         // gauss-jordan version
-        psTrace(__func__, 5, "using Gauss-J version");
+        psTrace("psLib.math", 5, "using Gauss-J version");
 
     // set new guess values (creates matrix A)
@@ -158,5 +158,5 @@
     psMinimizeLMChi2Func func)
 {
-    psTrace(__func__, 3, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() begin ----\n", __func__);
     // allocate internal arrays (current vs Guess)
     psImage  *alpha  = psImageAlloc (params->n, params->n, PS_TYPE_F64);
@@ -184,5 +184,5 @@
         rc = false;
     }
-    psTrace(__func__, 5, "p_psMinLM_SetABX() was succesful\n", __func__);
+    psTrace("psLib.math", 5, "p_psMinLM_SetABX() was succesful\n", __func__);
 
     psBool rcBool = p_psMinLM_GuessABP(Alpha, delta, Params, alpha, beta, params, paramMask, NULL, NULL, NULL, 0.0);
@@ -191,5 +191,5 @@
         rc = false;
     }
-    psTrace(__func__, 5, "p_psMinLM_GuessABP() was succesful\n", __func__);
+    psTrace("psLib.math", 5, "p_psMinLM_GuessABP() was succesful\n", __func__);
 
     psFree(alpha);
@@ -200,5 +200,5 @@
         psFree(dy);
     }
-    psTrace(__func__, 3, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() end ----\n", __func__);
     return(rc);
 }
@@ -335,5 +335,5 @@
     psMinimizeLMChi2Func func)
 {
-    psTrace(__func__, 3, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() begin ----\n", __func__);
     PS_ASSERT_PTR_NON_NULL(min, false);
     // XXX: If covar not NULL, do asserts...
@@ -415,7 +415,7 @@
     }
     if (psTraceGetLevel (__func__) >= 6) {
-        psTrace(__func__, 6, "The current Param vector: \n");
+        psTrace("psLib.math", 6, "The current Param vector: \n");
         for (psS32 i = 0 ; i < Params->n ; i++) {
-            psTrace(__func__, 6, "Params[%d] is %f\n", Params->data.F32[i]);
+            psTrace("psLib.math", 6, "Params[%d] is %f\n", Params->data.F32[i]);
         }
     }
@@ -423,6 +423,6 @@
     // iterate until the tolerance is reached, or give up
     while ((min->iter < min->maxIter) && ((min->lastDelta > min->tol) || !isfinite(min->lastDelta))) {
-        psTrace(__func__, 5, "Iteration number %d.  (max iterations is %d).\n", min->iter, min->maxIter);
-        psTrace(__func__, 5, "Last delta is %f.  Min->tol is %f.\n", min->lastDelta, min->tol);
+        psTrace("psLib.math", 5, "Iteration number %d.  (max iterations is %d).\n", min->iter, min->maxIter);
+        psTrace("psLib.math", 5, "Last delta is %f.  Min->tol is %f.\n", min->lastDelta, min->tol);
 
         // set a new guess for Alpha, Beta, Params
@@ -445,7 +445,7 @@
         if (psTraceGetLevel(__func__) >= 6) {
             if (psTraceGetLevel (__func__) >= 6) {
-                psTrace(__func__, 6, "The current Param vector: \n");
+                psTrace("psLib.math", 6, "The current Param vector: \n");
                 for (psS32 i = 0 ; i < Params->n ; i++) {
-                    psTrace(__func__, 6, "Params[%d] is %f\n", Params->data.F32[i]);
+                    psTrace("psLib.math", 6, "Params[%d] is %f\n", Params->data.F32[i]);
                 }
             }
@@ -466,5 +466,5 @@
         psF64 rho = (min->value - Chisq) / dLinear;
 
-        psTrace(__func__, 5, "last chisq: %f, new chisq %f, delta: %f, rho: %f\n", min->value,
+        psTrace("psLib.math", 5, "last chisq: %f, new chisq %f, delta: %f, rho: %f\n", min->value,
                 Chisq, min->lastDelta, rho);
 
@@ -489,5 +489,5 @@
         min->iter++;
     }
-    psTrace(__func__, 5, "chisq: %f, last delta: %f, Niter: %d\n", min->value, min->lastDelta, min->iter);
+    psTrace("psLib.math", 5, "chisq: %f, last delta: %f, Niter: %d\n", min->value, min->lastDelta, min->iter);
 
     // construct & return the covariance matrix (if requested)
@@ -509,8 +509,8 @@
     }
     if (min->iter == min->maxIter) {
-        psTrace(__func__, 3, "---- %s(false) end ----\n", __func__);
+        psTrace("psLib.math", 3, "---- %s(false) end ----\n", __func__);
         return(false);
     }
-    psTrace(__func__, 3, "---- %s(true) end ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s(true) end ----\n", __func__);
     return(true);
 }
Index: /trunk/psLib/src/math/psMinimizePolyFit.c
===================================================================
--- /trunk/psLib/src/math/psMinimizePolyFit.c	(revision 8244)
+++ /trunk/psLib/src/math/psMinimizePolyFit.c	(revision 8245)
@@ -10,6 +10,6 @@
  *  @author EAM, IfA
  *
- *  @version $Revision: 1.16 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-06-30 02:20:06 $
+ *  @version $Revision: 1.17 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-08-09 02:26:44 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -470,5 +470,5 @@
     const psVector *x)
 {
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
     PS_ASSERT_POLY_NON_NULL(myPoly, NULL);
     PS_ASSERT_VECTOR_NON_NULL(f, NULL);
@@ -488,16 +488,16 @@
 
     if (psTraceGetLevel(__func__) >= 6) {
-        psTrace(__func__, 6, "VectorFitPolynomial1D()\n");
+        psTrace("psLib.math", 6, "VectorFitPolynomial1D()\n");
         for (psS32 i = 0; i < f->n; i++) {
-            psTrace(__func__, 6, "(x, f, fErr) is (");
+            psTrace("psLib.math", 6, "(x, f, fErr) is (");
             if (x != NULL) {
-                psTrace(__func__, 6, "%f, %f, ", x->data.F64[i], f->data.F64[i]);
+                psTrace("psLib.math", 6, "%f, %f, ", x->data.F64[i], f->data.F64[i]);
             } else {
-                psTrace(__func__, 6, "%f, %f, ", (psF64) i, f->data.F64[i]);
+                psTrace("psLib.math", 6, "%f, %f, ", (psF64) i, f->data.F64[i]);
             }
             if (fErr != NULL) {
-                psTrace(__func__, 6, "%f)\n", fErr->data.F64[i]);
+                psTrace("psLib.math", 6, "%f)\n", fErr->data.F64[i]);
             } else {
-                psTrace(__func__, 6, "NULL)\n");
+                psTrace("psLib.math", 6, "NULL)\n");
             }
         }
@@ -516,5 +516,5 @@
         psFree(A);
         psFree(B);
-        psTrace(__func__, 4, "---- %s() End ----\n", __func__);
+        psTrace("psLib.math", 4, "---- %s() End ----\n", __func__);
         return(NULL);
     }
@@ -645,5 +645,5 @@
     psFree(B);
 
-    psTrace(__func__, 4, "---- %s() End ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() End ----\n", __func__);
     return (myPoly);
 }
@@ -754,5 +754,5 @@
     const psVector *xIn)
 {
-    psTrace(__func__, 3, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() begin ----\n", __func__);
     PS_ASSERT_POLY_NON_NULL(poly, NULL);
     PS_ASSERT_PTR_NON_NULL(stats, NULL);
@@ -811,15 +811,15 @@
     // for now, for the SAMPLE_MEDIAN and SAMPLE_STDEV to be used
     stats->options |= (PS_STAT_SAMPLE_MEDIAN | PS_STAT_SAMPLE_STDEV);
-    psTrace(__func__, 4, "stats->clipIter is %d\n", stats->clipIter);
-    psTrace(__func__, 4, "(minClipSigma, maxClipSigma) is (%.2f, %.2f)\n", minClipSigma, maxClipSigma);
+    psTrace("psLib.math", 4, "stats->clipIter is %d\n", stats->clipIter);
+    psTrace("psLib.math", 4, "(minClipSigma, maxClipSigma) is (%.2f, %.2f)\n", minClipSigma, maxClipSigma);
 
     //
     for (psS32 N = 0; N < stats->clipIter; N++) {
-        psTrace(__func__, 6, "Loop iteration %d.  Calling psVectorFitPolynomial1D()\n");
+        psTrace("psLib.math", 6, "Loop iteration %d.  Calling psVectorFitPolynomial1D()\n");
         psS32 Nkeep = 0;
         if (psTraceGetLevel(__func__) >= 6) {
             if (mask != NULL) {
                 for (psS32 i = 0 ; i < mask->n ; i++) {
-                    psTrace(__func__, 6,  "mask[%d] is %d\n", i, mask->data.U8[i]);
+                    psTrace("psLib.math", 6,  "mask[%d] is %d\n", i, mask->data.U8[i]);
                 }
             }
@@ -851,5 +851,5 @@
                 for (psS32 i = 0 ; i < mask->n ; i++) {
                     if (!((mask != NULL) && (mask->data.U8[i] & maskValue))) {
-                        psTrace(__func__, 6,  "(f, fit)[%d] is (%f, %f).  resid is (%f)\n",
+                        psTrace("psLib.math", 6,  "(f, fit)[%d] is (%f, %f).  resid is (%f)\n",
                                 i, f->data.F32[i], fit->data.F32[i], resid->data.F64[i]);
                     }
@@ -859,6 +859,6 @@
 
         stats  = psVectorStats(stats, resid, NULL, mask, maskValue);
-        psTrace(__func__, 6, "Median is %f\n", stats->sampleMedian);
-        psTrace(__func__, 6, "Stdev is %f\n", stats->sampleStdev);
+        psTrace("psLib.math", 6, "Median is %f\n", stats->sampleMedian);
+        psTrace("psLib.math", 6, "Stdev is %f\n", stats->sampleStdev);
         psF32 minClipValue = -minClipSigma*stats->sampleStdev;
         psF32 maxClipValue = +maxClipSigma*stats->sampleStdev;
@@ -875,8 +875,8 @@
                     (resid->data.F64[i] - stats->sampleMedian < minClipValue)) {
                 if (f->type.type == PS_TYPE_F64) {
-                    psTrace(__func__, 6, "Masking element %d (%f).  resid->data.F64[%d] is %f\n",
+                    psTrace("psLib.math", 6, "Masking element %d (%f).  resid->data.F64[%d] is %f\n",
                             i, fit->data.F64[i], i, resid->data.F64[i]);
                 } else {
-                    psTrace(__func__, 6, "Masking element %d (%f).  resid->data.F64[%d] is %f\n",
+                    psTrace("psLib.math", 6, "Masking element %d (%f).  resid->data.F64[%d] is %f\n",
                             i, fit->data.F32[i], i, resid->data.F64[i]);
                 }
@@ -894,5 +894,5 @@
         // since the polynomial fit won't change.
         //
-        psTrace(__func__, 6, "keeping %d of %d pts for fit\n", Nkeep, x->n);
+        psTrace("psLib.math", 6, "keeping %d of %d pts for fit\n", Nkeep, x->n);
         psFree(fit);
     }
@@ -905,5 +905,5 @@
     psFree(resid);
 
-    psTrace(__func__, 3, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() end ----\n", __func__);
     return (poly);
 }
@@ -931,5 +931,5 @@
     const psVector *y)
 {
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
     PS_ASSERT_POLY_NON_NULL(myPoly, NULL);
     PS_ASSERT_INT_NONNEGATIVE(myPoly->nX, NULL);
@@ -967,5 +967,5 @@
         psFree(A);
         psFree(B);
-        psTrace(__func__, 4, "---- %s() End ----\n", __func__);
+        psTrace("psLib.math", 4, "---- %s() End ----\n", __func__);
         return(NULL);
     }
@@ -1045,5 +1045,5 @@
     psFree(B);
 
-    psTrace(__func__, 4, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() end ----\n", __func__);
     return (myPoly);
 }
@@ -1201,5 +1201,5 @@
     const psVector *y)
 {
-    psTrace(__func__, 3, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() begin ----\n", __func__);
     PS_ASSERT_POLY_NON_NULL(poly, NULL);
     PS_ASSERT_POLY_TYPE(poly, PS_POLYNOMIAL_ORD, NULL);
@@ -1246,14 +1246,14 @@
     // for now, for the SAMPLE_MEDIAN and SAMPLE_STDEV to be used
     stats->options |= (PS_STAT_SAMPLE_MEDIAN | PS_STAT_SAMPLE_STDEV);
-    psTrace(__func__, 4, "stats->clipIter is %d\n", stats->clipIter);
-    psTrace(__func__, 4, "(minClipSigma, maxClipSigma) is (%.2f, %.2f)\n", minClipSigma, maxClipSigma);
+    psTrace("psLib.math", 4, "stats->clipIter is %d\n", stats->clipIter);
+    psTrace("psLib.math", 4, "(minClipSigma, maxClipSigma) is (%.2f, %.2f)\n", minClipSigma, maxClipSigma);
 
     for (psS32 N = 0; N < stats->clipIter; N++) {
-        psTrace(__func__, 6, "Loop iteration %d.  Calling psVectorFitPolynomial1D()\n");
+        psTrace("psLib.math", 6, "Loop iteration %d.  Calling psVectorFitPolynomial1D()\n");
         psS32 Nkeep = 0;
         if (psTraceGetLevel(__func__) >= 6) {
             if (mask != NULL) {
                 for (psS32 i = 0 ; i < mask->n ; i++) {
-                    psTrace(__func__, 6,  "mask[%d] is %d\n", i, mask->data.U8[i]);
+                    psTrace("psLib.math", 6,  "mask[%d] is %d\n", i, mask->data.U8[i]);
                 }
             }
@@ -1286,5 +1286,5 @@
                 for (psS32 i = 0 ; i < mask->n ; i++) {
                     if (!((mask != NULL) && (mask->data.U8[i] & maskValue))) {
-                        psTrace(__func__, 6,  "(f, fit)[%d] is (%f, %f).  resid is (%f)\n",
+                        psTrace("psLib.math", 6,  "(f, fit)[%d] is (%f, %f).  resid is (%f)\n",
                                 i, f->data.F32[i], fit->data.F32[i], resid->data.F64[i]);
                     }
@@ -1300,6 +1300,6 @@
             return(NULL);
         }
-        psTrace(__func__, 6, "Median is %f\n", stats->sampleMedian);
-        psTrace(__func__, 6, "Stdev is %f\n", stats->sampleStdev);
+        psTrace("psLib.math", 6, "Median is %f\n", stats->sampleMedian);
+        psTrace("psLib.math", 6, "Stdev is %f\n", stats->sampleStdev);
         psF32 minClipValue = -minClipSigma*stats->sampleStdev;
         psF32 maxClipValue = +maxClipSigma*stats->sampleStdev;
@@ -1316,8 +1316,8 @@
                     (resid->data.F64[i] - stats->sampleMedian < minClipValue)) {
                 if (fit->type.type == PS_TYPE_F64) {
-                    psTrace(__func__, 6, "Masking element %d (%f).  resid->data.F64[%d] is %f\n",
+                    psTrace("psLib.math", 6, "Masking element %d (%f).  resid->data.F64[%d] is %f\n",
                             i, fit->data.F64[i], i, resid->data.F64[i]);
                 } else {
-                    psTrace(__func__, 6, "Masking element %d (%f).  resid->data.F64[%d] is %f\n",
+                    psTrace("psLib.math", 6, "Masking element %d (%f).  resid->data.F64[%d] is %f\n",
                             i, fit->data.F32[i], i, resid->data.F64[i]);
                 }
@@ -1331,5 +1331,5 @@
         }
 
-        psTrace(__func__, 6, "keeping %d of %d pts for fit\n", Nkeep, x->n);
+        psTrace("psLib.math", 6, "keeping %d of %d pts for fit\n", Nkeep, x->n);
         psFree(fit);
     }
@@ -1342,5 +1342,5 @@
     }
 
-    psTrace(__func__, 3, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() end ----\n", __func__);
     return(poly);
 }
@@ -1369,5 +1369,5 @@
     const psVector *z)
 {
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
     PS_ASSERT_POLY_NON_NULL(myPoly, NULL);
     PS_ASSERT_INT_NONNEGATIVE(myPoly->nX, NULL);
@@ -1411,5 +1411,5 @@
         psFree(A);
         psFree(B);
-        psTrace(__func__, 4, "---- %s() End ----\n", __func__);
+        psTrace("psLib.math", 4, "---- %s() End ----\n", __func__);
         return(NULL);
     }
@@ -1543,5 +1543,5 @@
     psFree(B);
 
-    psTrace(__func__, 4, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() end ----\n", __func__);
     return (myPoly);
 }
@@ -1716,5 +1716,5 @@
     const psVector *z)
 {
-    psTrace(__func__, 3, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() begin ----\n", __func__);
     PS_ASSERT_POLY_NON_NULL(poly, NULL);
     PS_ASSERT_POLY_TYPE(poly, PS_POLYNOMIAL_ORD, NULL);
@@ -1766,14 +1766,14 @@
     // for now, for the SAMPLE_MEDIAN and SAMPLE_STDEV to be used
     stats->options |= (PS_STAT_SAMPLE_MEDIAN | PS_STAT_SAMPLE_STDEV);
-    psTrace(__func__, 4, "stats->clipIter is %d\n", stats->clipIter);
-    psTrace(__func__, 4, "(minClipSigma, maxClipSigma) is (%.2f, %.2f)\n", minClipSigma, maxClipSigma);
+    psTrace("psLib.math", 4, "stats->clipIter is %d\n", stats->clipIter);
+    psTrace("psLib.math", 4, "(minClipSigma, maxClipSigma) is (%.2f, %.2f)\n", minClipSigma, maxClipSigma);
 
     for (psS32 N = 0; N < stats->clipIter; N++) {
-        psTrace(__func__, 6, "Loop iteration %d.  Calling psVectorFitPolynomial1D()\n");
+        psTrace("psLib.math", 6, "Loop iteration %d.  Calling psVectorFitPolynomial1D()\n");
         psS32 Nkeep = 0;
         if (psTraceGetLevel(__func__) >= 6) {
             if (mask != NULL) {
                 for (psS32 i = 0 ; i < mask->n ; i++) {
-                    psTrace(__func__, 6,  "mask[%d] is %d\n", i, mask->data.U8[i]);
+                    psTrace("psLib.math", 6,  "mask[%d] is %d\n", i, mask->data.U8[i]);
                 }
             }
@@ -1805,5 +1805,5 @@
                 for (psS32 i = 0 ; i < mask->n ; i++) {
                     if (!((mask != NULL) && (mask->data.U8[i] & maskValue))) {
-                        psTrace(__func__, 6,  "(f, fit)[%d] is (%f, %f).  resid is (%f)\n",
+                        psTrace("psLib.math", 6,  "(f, fit)[%d] is (%f, %f).  resid is (%f)\n",
                                 i, f->data.F32[i], fit->data.F32[i], resid->data.F64[i]);
                     }
@@ -1820,6 +1820,6 @@
         }
 
-        psTrace(__func__, 6, "Median is %f\n", stats->sampleMedian);
-        psTrace(__func__, 6, "Stdev is %f\n", stats->sampleStdev);
+        psTrace("psLib.math", 6, "Median is %f\n", stats->sampleMedian);
+        psTrace("psLib.math", 6, "Stdev is %f\n", stats->sampleStdev);
         psF32 minClipValue = -minClipSigma*stats->sampleStdev;
         psF32 maxClipValue = +maxClipSigma*stats->sampleStdev;
@@ -1836,8 +1836,8 @@
                     (resid->data.F64[i] - stats->sampleMedian < minClipValue))  {
                 if (f->type.type == PS_TYPE_F64) {
-                    psTrace(__func__, 6, "Masking element %d (%f).  resid->data.F64[%d] is %f\n",
+                    psTrace("psLib.math", 6, "Masking element %d (%f).  resid->data.F64[%d] is %f\n",
                             i, fit->data.F64[i], i, resid->data.F64[i]);
                 } else {
-                    psTrace(__func__, 6, "Masking element %d (%f).  resid->data.F64[%d] is %f\n",
+                    psTrace("psLib.math", 6, "Masking element %d (%f).  resid->data.F64[%d] is %f\n",
                             i, fit->data.F32[i], i, resid->data.F64[i]);
                 }
@@ -1851,5 +1851,5 @@
         }
 
-        psTrace(__func__, 6, "keeping %d of %d pts for fit\n", Nkeep, x->n);
+        psTrace("psLib.math", 6, "keeping %d of %d pts for fit\n", Nkeep, x->n);
         psFree(fit);
     }
@@ -1862,5 +1862,5 @@
     }
 
-    psTrace(__func__, 3, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() end ----\n", __func__);
     return(poly);
 }
@@ -1888,5 +1888,5 @@
     const psVector *t)
 {
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
     PS_ASSERT_POLY_NON_NULL(myPoly, NULL);
     PS_ASSERT_INT_NONNEGATIVE(myPoly->nX, NULL);
@@ -1934,5 +1934,5 @@
         psFree(A);
         psFree(B);
-        psTrace(__func__, 4, "---- %s() End ----\n", __func__);
+        psTrace("psLib.math", 4, "---- %s() End ----\n", __func__);
         return(NULL);
     }
@@ -2079,5 +2079,5 @@
     psFree(B);
 
-    psTrace(__func__, 4, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() end ----\n", __func__);
     return (myPoly);
 }
@@ -2277,5 +2277,5 @@
     const psVector *t)
 {
-    psTrace(__func__, 3, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() begin ----\n", __func__);
     PS_ASSERT_POLY_NON_NULL(poly, NULL);
     PS_ASSERT_POLY_TYPE(poly, PS_POLYNOMIAL_ORD, NULL);
@@ -2331,14 +2331,14 @@
     // for now, for the SAMPLE_MEDIAN and SAMPLE_STDEV to be used
     stats->options |= (PS_STAT_SAMPLE_MEDIAN | PS_STAT_SAMPLE_STDEV);
-    psTrace(__func__, 4, "stats->clipIter is %d\n", stats->clipIter);
-    psTrace(__func__, 4, "(minClipSigma, maxClipSigma) is (%.2f, %.2f)\n", minClipSigma, maxClipSigma);
+    psTrace("psLib.math", 4, "stats->clipIter is %d\n", stats->clipIter);
+    psTrace("psLib.math", 4, "(minClipSigma, maxClipSigma) is (%.2f, %.2f)\n", minClipSigma, maxClipSigma);
 
     for (psS32 N = 0; N < stats->clipIter; N++) {
-        psTrace(__func__, 6, "Loop iteration %d.  Calling psVectorFitPolynomial4D()\n");
+        psTrace("psLib.math", 6, "Loop iteration %d.  Calling psVectorFitPolynomial4D()\n");
         psS32 Nkeep = 0;
         if (psTraceGetLevel(__func__) >= 6) {
             if (mask != NULL) {
                 for (psS32 i = 0 ; i < mask->n ; i++) {
-                    psTrace(__func__, 6,  "mask[%d] is %d\n", i, mask->data.U8[i]);
+                    psTrace("psLib.math", 6,  "mask[%d] is %d\n", i, mask->data.U8[i]);
                 }
             }
@@ -2371,5 +2371,5 @@
                 for (psS32 i = 0 ; i < mask->n ; i++) {
                     if (!((mask != NULL) && (mask->data.U8[i] & maskValue))) {
-                        psTrace(__func__, 6,  "(f, fit)[%d] is (%f, %f).  resid is (%f)\n",
+                        psTrace("psLib.math", 6,  "(f, fit)[%d] is (%f, %f).  resid is (%f)\n",
                                 i, f->data.F32[i], fit->data.F32[i], resid->data.F64[i]);
                     }
@@ -2385,6 +2385,6 @@
             return(NULL);
         }
-        psTrace(__func__, 6, "Median is %f\n", stats->sampleMedian);
-        psTrace(__func__, 6, "Stdev is %f\n", stats->sampleStdev);
+        psTrace("psLib.math", 6, "Median is %f\n", stats->sampleMedian);
+        psTrace("psLib.math", 6, "Stdev is %f\n", stats->sampleStdev);
         psF32 minClipValue = -minClipSigma*stats->sampleStdev;
         psF32 maxClipValue = +maxClipSigma*stats->sampleStdev;
@@ -2401,8 +2401,8 @@
                     (resid->data.F64[i] - stats->sampleMedian < minClipValue)) {
                 if (f->type.type == PS_TYPE_F64) {
-                    psTrace(__func__, 6, "Masking element %d (%f).  resid->data.F64[%d] is %f\n",
+                    psTrace("psLib.math", 6, "Masking element %d (%f).  resid->data.F64[%d] is %f\n",
                             i, fit->data.F64[i], i, resid->data.F64[i]);
                 } else {
-                    psTrace(__func__, 6, "Masking element %d (%f).  resid->data.F64[%d] is %f\n",
+                    psTrace("psLib.math", 6, "Masking element %d (%f).  resid->data.F64[%d] is %f\n",
                             i, fit->data.F32[i], i, resid->data.F64[i]);
                 }
@@ -2417,5 +2417,5 @@
         }
 
-        psTrace(__func__, 6, "keeping %d of %d pts for fit\n", Nkeep, x->n);
+        psTrace("psLib.math", 6, "keeping %d of %d pts for fit\n", Nkeep, x->n);
         psFree (fit);
     }
@@ -2428,5 +2428,5 @@
     }
 
-    psTrace(__func__, 3, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() end ----\n", __func__);
     return(poly);
 }
Index: /trunk/psLib/src/math/psMinimizePowell.c
===================================================================
--- /trunk/psLib/src/math/psMinimizePowell.c	(revision 8244)
+++ /trunk/psLib/src/math/psMinimizePowell.c	(revision 8245)
@@ -11,6 +11,6 @@
  *  NOTE: XXX: The SDR is silent about data types.  F32 is implemented here.
  *
- *  @version $Revision: 1.9 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-06-30 02:20:06 $
+ *  @version $Revision: 1.10 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-08-09 02:26:44 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -117,11 +117,11 @@
     psBool boolLineIsNull = true;
 
-    psTrace(__func__, 4, "---- p_psDetermineBracket() begin ----\n");
+    psTrace("psLib.math", 4, "---- p_psDetermineBracket() begin ----\n");
 
     // If the line vector is zero, then return NULL.
     PS_VECTOR_WITH_MASK_F32_CHECK_ZERO_VECTOR(params, paramMask, boolLineIsNull);
     if (boolLineIsNull == true) {
-        psTrace(__func__, 2, "p_psDetermineBracket() called with zero line vector.\n");
-        psTrace(__func__, 4, "---- p_psDetermineBracket() end (NULL) ----\n");
+        psTrace("psLib.math", 2, "p_psDetermineBracket() called with zero line vector.\n");
+        psTrace("psLib.math", 4, "---- p_psDetermineBracket() end (NULL) ----\n");
         psFree(bracket);
         return(NULL);
@@ -155,8 +155,8 @@
     }
 
-    psTrace(__func__, 6, "(a, b, c) is (%f %f %f) (fa, fb, fc) is (%f %f %f)\n", a, b, c, fa, fb, fc);
+    psTrace("psLib.math", 6, "(a, b, c) is (%f %f %f) (fa, fb, fc) is (%f %f %f)\n", a, b, c, fa, fb, fc);
 
     while (iter > 0) {
-        psTrace(__func__, 6, "psDetermineBracket(): iteration %d\n", iter);
+        psTrace("psLib.math", 6, "psDetermineBracket(): iteration %d\n", iter);
         if ((fb < fa) && (fb < fc)) {
             bracket->data.F32[0] = a;
@@ -164,5 +164,5 @@
             bracket->data.F32[2] = c;
             psFree(tmp);
-            psTrace(__func__, 6, "---- p_psDetermineBracket() end ----\n");
+            psTrace("psLib.math", 6, "---- p_psDetermineBracket() end ----\n");
             return(bracket);
         }
@@ -177,5 +177,5 @@
         fc = func(tmp, coords);
 
-        psTrace(__func__, 6, "Iter(%d): (a, b, c) is (%f %f %f) (fa, fb, fc) is (%f %f %f)\n", iter, a, b, c, fa, fb, fc);
+        psTrace("psLib.math", 6, "Iter(%d): (a, b, c) is (%f %f %f) (fa, fb, fc) is (%f %f %f)\n", iter, a, b, c, fa, fb, fc);
 
         if (fa < fb) {
@@ -195,5 +195,5 @@
             bracket->data.F32[2] = c;
             psFree(tmp);
-            psTrace(__func__, 4, "---- p_psDetermineBracket() end ----\n");
+            psTrace("psLib.math", 4, "---- p_psDetermineBracket() end ----\n");
             return(bracket);
         }
@@ -204,5 +204,5 @@
             bracket->data.F32[2] = c;
             psFree(tmp);
-            psTrace(__func__, 4, "---- p_psDetermineBracket() end ----\n");
+            psTrace("psLib.math", 4, "---- p_psDetermineBracket() end ----\n");
             return(bracket);
         }
@@ -213,5 +213,5 @@
     psFree(tmp);
     psFree(bracket);
-    psTrace(__func__, 4, "---- p_psDetermineBracket() end (NULL) ----\n");
+    psTrace("psLib.math", 4, "---- p_psDetermineBracket() end (NULL) ----\n");
     return(NULL);
 }
@@ -228,6 +228,6 @@
     bracket->data.F32[2] = a; \
 } \
-psTrace(__func__, 4, "Final bracket (a, b, c) is (%f %f %f) (fa, fb, fc) is (%f %f %f)\n", a, b, c, fa, fb, fc); \
-psTrace(__func__, 4, "---- p_psDetermineBracket() end ----\n"); \
+psTrace("psLib.math", 4, "Final bracket (a, b, c) is (%f %f %f) (fa, fb, fc) is (%f %f %f)\n", a, b, c, fa, fb, fc); \
+psTrace("psLib.math", 4, "---- p_psDetermineBracket() end ----\n"); \
 psFree(tmp); \
 return(bracket); \
@@ -253,11 +253,11 @@
     psS32 countMin = 0;
 
-    psTrace(__func__, 4, "---- p_psDetermineBracket() begin ----\n");
+    psTrace("psLib.math", 4, "---- p_psDetermineBracket() begin ----\n");
 
     // If the line vector is zero, then return NULL.
     PS_VECTOR_WITH_MASK_F32_CHECK_ZERO_VECTOR(params, paramMask, boolLineIsNull);
     if (boolLineIsNull == true) {
-        psTrace(__func__, 2, "p_psDetermineBracket() called with zero line vector.\n");
-        psTrace(__func__, 4, "---- p_psDetermineBracket() end (NULL) ----\n");
+        psTrace("psLib.math", 2, "p_psDetermineBracket() called with zero line vector.\n");
+        psTrace("psLib.math", 4, "---- p_psDetermineBracket() end (NULL) ----\n");
         psFree(tmp);
         return(NULL);
@@ -289,5 +289,5 @@
     iter = 0;
     while (iter < PS_DETERMINE_BRACKET_MAX_ITERATIONS) {
-        psTrace(__func__, 6, "psDetermineBracket(): iterationA %d\n", iter);
+        psTrace("psLib.math", 6, "psDetermineBracket(): iterationA %d\n", iter);
         c+= (1.0 + PS_DETERMINE_BRACKET_STEP_SIZE) * (c - a);
 
@@ -295,5 +295,5 @@
         fc = func(tmp, coords);
 
-        psTrace(__func__, 6, "Iteration(%d) (bracket): (a, b, c) is (%f %f %f) (fa, fb, fc) is (%f %f %f)\n", iter, a, b, c, fa, fb, fc);
+        psTrace("psLib.math", 6, "Iteration(%d) (bracket): (a, b, c) is (%f %f %f) (fa, fb, fc) is (%f %f %f)\n", iter, a, b, c, fa, fb, fc);
 
         if ((fb < fa) && (fb < fc)) {
@@ -320,5 +320,5 @@
 
     psFree(bracket);
-    psTrace(__func__, 4, "---- p_psDetermineBracket() end (NULL) (BAD) ----\n");
+    psTrace("psLib.math", 4, "---- p_psDetermineBracket() end (NULL) (BAD) ----\n");
     return(NULL);
 }
@@ -371,10 +371,10 @@
     psS32 numIterations = 0;
 
-    psTrace(__func__, 4, "---- LineMin() begin ----\n");
+    psTrace("psLib.math", 4, "---- LineMin() begin ----\n");
     PS_VECTOR_F32_CHECK_ZERO_VECTOR(line, boolLineIsNull);
 
     if (boolLineIsNull == true) {
         min->value = func(params, coords);
-        psTrace(__func__, 2, "LineMin() called with zero line vector.  Return 0.0.  Function value is %f\n", min->value);
+        psTrace("psLib.math", 2, "LineMin() called with zero line vector.  Return 0.0.  Function value is %f\n", min->value);
         return(0.0);
     }
@@ -382,5 +382,5 @@
     if (6 <= psTraceGetLevel(__func__)) {
         for (i=0;i<params->n;i++) {
-            psTrace(__func__, 6, "(params, paramMask, line)[%d] is (%f %d %f)\n", i,
+            psTrace("psLib.math", 6, "(params, paramMask, line)[%d] is (%f %d %f)\n", i,
                     params->data.F32[i], paramMask->data.U8[i], line->data.F32[i]);
         }
@@ -402,5 +402,5 @@
     while (numIterations < PS_LINEMIN_MAX_ITERATIONS) {
         numIterations++;
-        psTrace(__func__, 6, "LineMin(): iteration %d\n", numIterations);
+        psTrace("psLib.math", 6, "LineMin(): iteration %d\n", numIterations);
 
         a = bracket->data.F32[0];
@@ -413,5 +413,5 @@
         fb = func(tmpb, coords);
         fc = func(tmpc, coords);
-        psTrace(__func__, 6, "LineMin: f(%f %f %f) is (%f %f %f)\n", a, b, c, fa, fb, fc);
+        psTrace("psLib.math", 6, "LineMin: f(%f %f %f) is (%f %f %f)\n", a, b, c, fa, fb, fc);
 
         // We determine which is the biggest segment in [a,b,c] then split
@@ -449,5 +449,5 @@
             }
         }
-        psTrace(__func__, 6, "LineMin: new bracket is (%f %f %f)\n", bracket->data.F32[0], bracket->data.F32[1], bracket->data.F32[2]);
+        psTrace("psLib.math", 6, "LineMin: new bracket is (%f %f %f)\n", bracket->data.F32[0], bracket->data.F32[1], bracket->data.F32[2]);
 
         mul = bracket->data.F32[1];
@@ -456,5 +456,5 @@
             min->value = func(params, coords);
             psFree(bracket);
-            psTrace(__func__, 4, "---- LineMin() end.a (%f) (%f) ----\n", mul, min->value);
+            psTrace("psLib.math", 4, "---- LineMin() end.a (%f) (%f) ----\n", mul, min->value);
             psFree(tmpa);
             psFree(tmpb);
@@ -468,5 +468,5 @@
     PS_VECTOR_ADD_MULTIPLE(params, paramMask, line, params, mul);
     min->value = func(params, coords);
-    psTrace(__func__, 4, "---- LineMin() end.b (%f) %f ----\n", mul, min->value);
+    psTrace("psLib.math", 4, "---- LineMin() end.b (%f) %f ----\n", mul, min->value);
 
     psFree(bracket);
@@ -517,7 +517,7 @@
     psS32 iterationNumber = 0;
 
-    psTrace(__func__, 4, "---- psMinimizePowell() begin ----\n");
-    psTrace(__func__, 6, "min->maxIter is %d\n", min->maxIter);
-    psTrace(__func__, 6, "min->tol is %f\n", min->tol);
+    psTrace("psLib.math", 4, "---- psMinimizePowell() begin ----\n");
+    psTrace("psLib.math", 6, "min->maxIter is %d\n", min->maxIter);
+    psTrace("psLib.math", 6, "min->tol is %f\n", min->tol);
 
     if (paramMask == NULL) {
@@ -562,5 +562,5 @@
     while (iterationNumber < min->maxIter) {
         iterationNumber++;
-        psTrace(__func__, 6, "psMinimizePowell() iteration %d\n", iterationNumber);
+        psTrace("psLib.math", 6, "psMinimizePowell() iteration %d\n", iterationNumber);
 
         // 3: For each dimension in params, move Q only in the vector v[i] to
@@ -569,5 +569,5 @@
         baseFuncVal = func(Q, coords);
         currFuncVal = baseFuncVal;
-        psTrace(__func__, 6, "Current function value is %f\n", currFuncVal);
+        psTrace("psLib.math", 6, "Current function value is %f\n", currFuncVal);
 
         biggestDiff = 0;
@@ -588,5 +588,5 @@
                     return(false);
                 }
-                psTrace(__func__, 6, "LineMin along dimension %d has multiple %f\n", i, mul);
+                psTrace("psLib.math", 6, "LineMin along dimension %d has multiple %f\n", i, mul);
 
                 if (fabs(dummyMin.value - currFuncVal) > biggestDiff) {
@@ -598,5 +598,5 @@
             // XXX: how can it be that we are not saving mul anywhere?
         }
-        psTrace(__func__, 6, "New function value is %f\n", currFuncVal);
+        psTrace("psLib.math", 6, "New function value is %f\n", currFuncVal);
         // XXX: There must be a bug here.  How can currFuncVal be the current function value?
         // It is simply the minimum along one of the parameter dimensions.
@@ -608,5 +608,5 @@
                 u->n++;
 
-                psTrace(__func__, 6, "u[i]=Q[i]-P[i] (%f = %f - %f)\n", u->data.F32[i],
+                psTrace("psLib.math", 6, "u[i]=Q[i]-P[i] (%f = %f - %f)\n", u->data.F32[i],
                         Q->data.F32[i],
                         params->data.F32[i]);
@@ -620,5 +620,5 @@
         // 5: Move Q only in the direction u, and minimize the function.
         for (i=0;i<numDims;i++) {
-            psTrace(__func__, 6, "u[i] is %f\n", u->data.F32[i]);
+            psTrace("psLib.math", 6, "u[i] is %f\n", u->data.F32[i]);
         }
 
@@ -643,5 +643,5 @@
             min->value = currFuncVal;
             min->lastDelta = 0.0;
-            psTrace(__func__, 4, "---- psMinimizePowell() end (1)(true) ----\n");
+            psTrace("psLib.math", 4, "---- psMinimizePowell() end (1)(true) ----\n");
             return(true);
         }
@@ -685,5 +685,5 @@
             min->iter = iterationNumber;
             min->lastDelta = currFuncVal - baseFuncVal;
-            psTrace(__func__, 4, "---- psMinimizePowell() end (2) (true) ----\n");
+            psTrace("psLib.math", 4, "---- psMinimizePowell() end (2) (true) ----\n");
             return(true);
         }
@@ -695,5 +695,5 @@
     psFree(Q);
     min->iter = iterationNumber;
-    psTrace(__func__, 4, "---- psMinimizePowell() end (0) (false) ----\n");
+    psTrace("psLib.math", 4, "---- psMinimizePowell() end (0) (false) ----\n");
     return(false);
 }
@@ -712,5 +712,5 @@
     const psArray *coords)
 {
-    psTrace(__func__, 4, "---- myPowellChi2Func() begin ----\n");
+    psTrace("psLib.math", 4, "---- myPowellChi2Func() begin ----\n");
     PS_ASSERT_VECTOR_NON_NULL(params, NAN);
     PS_ASSERT_VECTOR_NON_EMPTY(params, NAN);
@@ -750,5 +750,5 @@
     }
     psFree(tmp);
-    psTrace(__func__, 4, "---- myPowellChi2Func() end (chi2 is %f) ----\n", chi2);
+    psTrace("psLib.math", 4, "---- myPowellChi2Func() end (chi2 is %f) ----\n", chi2);
     return(chi2);
 }
Index: /trunk/psLib/src/math/psPolynomial.c
===================================================================
--- /trunk/psLib/src/math/psPolynomial.c	(revision 8244)
+++ /trunk/psLib/src/math/psPolynomial.c	(revision 8245)
@@ -7,6 +7,6 @@
 *  polynomials.  It also contains a Gaussian functions.
 *
-*  @version $Revision: 1.148 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2006-08-08 23:32:23 $
+*  @version $Revision: 1.149 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2006-08-09 02:26:44 $
 *
 *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -217,13 +217,13 @@
     psF64 xSum = 1.0;
 
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
-    psTrace(__func__, 4, "Polynomial order is %u\n", poly->nX);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 4, "Polynomial order is %u\n", poly->nX);
     for (loop_x = 0; loop_x < poly->nX+1; loop_x++) {
-        psTrace(__func__, 4, "Polynomial coeff[%u] is %lf\n", loop_x, poly->coeff[loop_x]);
+        psTrace("psLib.math", 4, "Polynomial coeff[%u] is %lf\n", loop_x, poly->coeff[loop_x]);
     }
 
     for (loop_x = 0; loop_x < poly->nX+1; loop_x++) {
         if (poly->mask[loop_x] == 0) {
-            psTrace(__func__, 8,
+            psTrace("psLib.math", 8,
                     "polysum+= sum*coeff [%lf+= (%lf * %lf)\n", polySum, xSum, poly->coeff[loop_x]);
             polySum += xSum * poly->coeff[loop_x];
@@ -232,5 +232,5 @@
     }
 
-    psTrace(__func__, 4, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() end ----\n", __func__);
     return(polySum);
 }
@@ -571,5 +571,5 @@
     psF32 tmp = 1.0;
 
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
 
     if (normal == true) {
@@ -577,5 +577,5 @@
     }
 
-    psTrace(__func__, 4, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() end ----\n", __func__);
     return(tmp * exp(-((x - mean) * (x - mean)) / (2.0 * sigma * sigma)));
 }
Index: /trunk/psLib/src/math/psSpline.c
===================================================================
--- /trunk/psLib/src/math/psSpline.c	(revision 8244)
+++ /trunk/psLib/src/math/psSpline.c	(revision 8245)
@@ -6,6 +6,6 @@
 *  This file contains the routines that allocate, free, and evaluate splines.
 *
-*  @version $Revision: 1.151 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2006-08-08 23:32:23 $
+*  @version $Revision: 1.152 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2006-08-09 02:26:44 $
 *
 *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -119,5 +119,5 @@
     const psVector* y)                  ///< Coordinates
 {
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
     if (psTraceGetLevel(__func__) >= 6) {
         p_psVectorPrint(1, (psVector *) x, "x");
@@ -143,7 +143,7 @@
         u[i] = ((6.0 * u[i] / (X[i+1] - X[i-1])) - (sig * u[i-1])) / p;
 
-        psTrace(__func__, 6, "X[%d] is %f\n", i, X[i]);
-        psTrace(__func__, 6, "Y[%d] is %f\n", i, Y[i]);
-        psTrace(__func__, 6, "u[%d] is %f\n", i, u[i]);
+        psTrace("psLib.math", 6, "X[%d] is %f\n", i, X[i]);
+        psTrace("psLib.math", 6, "Y[%d] is %f\n", i, Y[i]);
+        psTrace("psLib.math", 6, "u[%d] is %f\n", i, u[i]);
     }
 
@@ -154,8 +154,8 @@
     for (psS32 k=(n-2);k>=0;k--) {
         derivs2[k] = derivs2[k] * derivs2[k+1] + u[k];
-        psTrace(__func__, 6, "derivs2[%d] is %f\n", k, derivs2[k]);
+        psTrace("psLib.math", 6, "derivs2[%d] is %f\n", k, derivs2[k]);
     }
     psFree(u);
-    psTrace(__func__, 4, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() end ----\n", __func__);
     return(derivs2);
 }
@@ -210,10 +210,10 @@
     const psVector* y)                  ///< Coordinates.
 {
-    psTrace(__func__, 3, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() begin ----\n", __func__);
     PS_ASSERT_VECTOR_NON_NULL(y, NULL);
     PS_ASSERT_VECTOR_TYPE_F32_OR_F64(y, NULL);
     PS_ASSERT_INT_LARGER_THAN_OR_EQUAL(y->n, 2, NULL);
     psS32 numSplines = (y->n)-1;
-    psTrace(__func__, 5, "numSplines is %d\n", numSplines);
+    psTrace("psLib.math", 5, "numSplines is %d\n", numSplines);
 
     //
@@ -281,5 +281,5 @@
                     i, i+1, xPtr->data.F32[i], xPtr->data.F32[i+1]);
         }
-        psTrace(__func__, 6, "x data (%f - %f) (%f)\n", xPtr->data.F32[i], xPtr->data.F32[i+1], H);
+        psTrace("psLib.math", 6, "x data (%f - %f) (%f)\n", xPtr->data.F32[i], xPtr->data.F32[i+1], H);
         //
         // ******** Calculate 0-order term ********
@@ -334,8 +334,8 @@
         spline->spline[i]->coeff[3]+=  spline->p_psDeriv2[i+1] / (6.0 * H);
 
-        psTrace(__func__, 6, "(spline->spline[%u])->coeff[0] is %f\n", i, spline->spline[i]->coeff[0]);
-        psTrace(__func__, 6, "(spline->spline[%u])->coeff[1] is %f\n", i, spline->spline[i]->coeff[1]);
-        psTrace(__func__, 6, "(spline->spline[%u])->coeff[2] is %f\n", i, spline->spline[i]->coeff[2]);
-        psTrace(__func__, 6, "(spline->spline[%u])->coeff[3] is %f\n", i, spline->spline[i]->coeff[3]);
+        psTrace("psLib.math", 6, "(spline->spline[%u])->coeff[0] is %f\n", i, spline->spline[i]->coeff[0]);
+        psTrace("psLib.math", 6, "(spline->spline[%u])->coeff[1] is %f\n", i, spline->spline[i]->coeff[1]);
+        psTrace("psLib.math", 6, "(spline->spline[%u])->coeff[2] is %f\n", i, spline->spline[i]->coeff[2]);
+        psTrace("psLib.math", 6, "(spline->spline[%u])->coeff[3] is %f\n", i, spline->spline[i]->coeff[3]);
     }
 
@@ -343,5 +343,5 @@
         psFree(yPtr);
     }
-    psTrace(__func__, 3, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() end ----\n", __func__);
     return(spline);
 }
@@ -365,5 +365,5 @@
     float x)
 {
-    psTrace(__func__, 3, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() begin ----\n", __func__);
     PS_ASSERT_PTR_NON_NULL(spline, NAN);
     PS_ASSERT_INT_NONNEGATIVE(spline->n, NAN);
@@ -379,5 +379,5 @@
 
         psS32 binNum = (x < spline->knots->data.F32[0]) ? 0 : n-1;
-        psTrace(__func__, 3, "---- %s() end ----\n", __func__);
+        psTrace("psLib.math", 3, "---- %s() end ----\n", __func__);
         return(psPolynomial1DEval(spline->spline[binNum], x));
     }
@@ -392,5 +392,5 @@
     }
 
-    psTrace(__func__, 3, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() end ----\n", __func__);
     return(psPolynomial1DEval(spline->spline[binNum], x));
 }
@@ -403,5 +403,5 @@
     const psVector *x)
 {
-    psTrace(__func__, 3, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() begin ----\n", __func__);
     PS_ASSERT_PTR_NON_NULL(spline, NULL);
     PS_ASSERT_VECTOR_TYPE(spline->knots, PS_TYPE_F32, NULL);
@@ -426,5 +426,5 @@
     }
 
-    psTrace(__func__, 3, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() end ----\n", __func__);
     return(tmpVector);
 }
Index: /trunk/psLib/src/math/psStats.c
===================================================================
--- /trunk/psLib/src/math/psStats.c	(revision 8244)
+++ /trunk/psLib/src/math/psStats.c	(revision 8245)
@@ -16,6 +16,6 @@
  * use ->min and ->max (PS_STAT_USE_RANGE)
  *
- *  @version $Revision: 1.183 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-08-08 23:32:23 $
+ *  @version $Revision: 1.184 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-08-09 02:26:44 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -110,5 +110,5 @@
                              psStats* stats)
 {
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
 
     psF32 mean = 0.0;                   // The mean
@@ -221,9 +221,9 @@
     stats->sampleMean = mean;
     if (isnan(mean)) {
-        psTrace(__func__, 4, "---- %s(false) end ----\n", __func__);
+        psTrace("psLib.math", 4, "---- %s(false) end ----\n", __func__);
         return false;
     }
 
-    psTrace(__func__, 4, "---- %s(true) end ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s(true) end ----\n", __func__);
     return true;
 }
@@ -240,5 +240,5 @@
                         )
 {
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
     psF32 max = -PS_MAX_F32;            // The calculated maximum
     psF32 min = PS_MAX_F32;             // The calculated minimum
@@ -316,5 +316,5 @@
         stats->min = min;
     }
-    psTrace(__func__, 4, "---- %s(%d) end ----\n", __func__, numValid);
+    psTrace("psLib.math", 4, "---- %s(%d) end ----\n", __func__, numValid);
     return numValid;
 }
@@ -332,5 +332,5 @@
                                 psStats* stats)
 {
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
     PS_ASSERT_VECTOR_NON_NULL(myVector, false);
     PS_ASSERT_PTR_NON_NULL(stats, false);
@@ -342,5 +342,5 @@
                         (stats->min <= myVector->data.F32[i]) &&
                         (myVector->data.F32[i] <= stats->max)) {
-                    psTrace(__func__, 4, "---- %s(true) end ----\n", __func__);
+                    psTrace("psLib.math", 4, "---- %s(true) end ----\n", __func__);
                     return true;
                 }
@@ -350,5 +350,5 @@
                 if ((stats->min <= myVector->data.F32[i]) &&
                         (myVector->data.F32[i] <= stats->max)) {
-                    psTrace(__func__, 4, "---- %s(true) end ----\n", __func__);
+                    psTrace("psLib.math", 4, "---- %s(true) end ----\n", __func__);
                     return true;
                 }
@@ -359,5 +359,5 @@
             for (long i = 0; i < myVector->n; i++) {
                 if (!(maskVal & maskVector->data.U8[i])) {
-                    psTrace(__func__, 4, "---- %s(true) end ----\n", __func__);
+                    psTrace("psLib.math", 4, "---- %s(true) end ----\n", __func__);
                     return true;
                 }
@@ -365,10 +365,10 @@
         } else {
             if (myVector->n > 0) {
-                psTrace(__func__, 4, "---- %s(true) end ----\n", __func__);
+                psTrace("psLib.math", 4, "---- %s(true) end ----\n", __func__);
                 return true;
             }
         }
     }
-    psTrace(__func__, 4, "---- %s(false) end ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s(false) end ----\n", __func__);
     return(false);
 }
@@ -385,5 +385,5 @@
                                psStats* stats)
 {
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
 
     // Allocate temporary vectors for the data.
@@ -441,5 +441,5 @@
                 false,
                 _("Failed to sort input data."));
-        psTrace(__func__, 4, "---- %s(false) end ----\n", __func__);
+        psTrace("psLib.math", 4, "---- %s(false) end ----\n", __func__);
         psFree(vector);
         return false;
@@ -463,5 +463,5 @@
 
     // Return "true" on success.
-    psTrace(__func__, 4, "---- %s(true) end ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s(true) end ----\n", __func__);
     return true;
 }
@@ -475,6 +475,6 @@
                                    psF32 sigma)
 {
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
-    psTrace(__func__, 5, "(histogram->nums->n, sigma) is (%d, %.2f\n", (int) histogram->nums->n, sigma);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 5, "(histogram->nums->n, sigma) is (%d, %.2f\n", (int) histogram->nums->n, sigma);
     PS_ASSERT_PTR_NON_NULL(histogram, NULL);
     PS_ASSERT_PTR_NON_NULL(histogram->bounds, NULL);
@@ -564,5 +564,5 @@
         PS_VECTOR_PRINT_F32(smooth);
     }
-    psTrace(__func__, 4, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() end ----\n", __func__);
     return(smooth);
 }
@@ -586,5 +586,5 @@
                               psStats* stats)
 {
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
 
     // This procedure requires the mean.  If it has not been already
@@ -597,5 +597,5 @@
         stats->sampleStdev = NAN;
         psLogMsg(__func__, PS_LOG_WARN, "WARNING: vectorSampleStdev(): vectorSampleMean() reported a NAN mean.\n");
-        psTrace(__func__, 4, "---- %s() end ----\n", __func__);
+        psTrace("psLib.math", 4, "---- %s() end ----\n", __func__);
         return false;
     }
@@ -680,5 +680,5 @@
                                   (float)(count - 1));
     }
-    psTrace(__func__, 4, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() end ----\n", __func__);
 
     return true;
@@ -704,6 +704,6 @@
                               )
 {
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
-    psTrace(__func__, 4, "Trace level is %d\n", psTraceGetLevel(__func__));
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 4, "Trace level is %d\n", psTraceGetLevel(__func__));
 
     // Ensure that stats->clipIter is within the proper range.
@@ -739,10 +739,10 @@
         stats->clippedMean = NAN;
         stats->clippedStdev = NAN;
-        psTrace(__func__, 4, "---- %s(false) end ----\n", __func__);
+        psTrace("psLib.math", 4, "---- %s(false) end ----\n", __func__);
         psFree(tmpMask);
         psFree(statsTmp);
         return false;
     }
-    psTrace(__func__, 6, "The initial sample median is %f\n", statsTmp->sampleMedian);
+    psTrace("psLib.math", 6, "The initial sample median is %f\n", statsTmp->sampleMedian);
 
     // 2. Compute the sample standard deviation.
@@ -752,10 +752,10 @@
         stats->clippedMean = NAN;
         stats->clippedStdev = NAN;
-        psTrace(__func__, 4, "---- %s(false) end ----\n", __func__);
+        psTrace("psLib.math", 4, "---- %s(false) end ----\n", __func__);
         psFree(tmpMask);
         psFree(statsTmp);
         return false;
     }
-    psTrace(__func__, 6, "The initial sample stdev is %f\n", statsTmp->sampleStdev);
+    psTrace("psLib.math", 6, "The initial sample stdev is %f\n", statsTmp->sampleStdev);
 
     // 3. Use the sample median as the first estimator of the mean X.
@@ -770,5 +770,5 @@
     for (int iter = 0; iter < stats->clipIter && clipped; iter++) {
         clipped = false;
-        psTrace(__func__, 6, "------------ Iteration %d ------------\n", iter);
+        psTrace("psLib.math", 6, "------------ Iteration %d ------------\n", iter);
         // a) Exclude all values x_i for which |x_i - x| > K * stdev
         if (errors) {
@@ -777,5 +777,5 @@
                         fabsf(myVector->data.F32[j] - clippedMean) > stats->clipSigma * errors->data.F32[j]) {
                     tmpMask->data.U8[j] = 0xff;
-                    psTrace(__func__, 10, "Clipped %d: %f +/- %f\n", j,
+                    psTrace("psLib.math", 10, "Clipped %d: %f +/- %f\n", j,
                             myVector->data.F32[j], errors->data.F32[j]);
                     numClipped++;
@@ -788,5 +788,5 @@
                         fabsf(myVector->data.F32[j] - clippedMean) > (stats->clipSigma * clippedStdev)) {
                     tmpMask->data.U8[j] = 0xff;
-                    psTrace(__func__, 10, "Clipped %d: %f\n", j, myVector->data.F32[j]);
+                    psTrace("psLib.math", 10, "Clipped %d: %f\n", j, myVector->data.F32[j]);
                     numClipped++;
                     clipped = true;
@@ -798,6 +798,6 @@
         vectorSampleMean(myVector, errors, tmpMask, maskVal, statsTmp);
         vectorSampleStdev(myVector, errors, tmpMask, maskVal, statsTmp);
-        psTrace(__func__, 6, "The new sample mean is %f\n", statsTmp->sampleMean);
-        psTrace(__func__, 6, "The new sample stdev is %f\n", statsTmp->sampleStdev);
+        psTrace("psLib.math", 6, "The new sample mean is %f\n", statsTmp->sampleMean);
+        psTrace("psLib.math", 6, "The new sample stdev is %f\n", statsTmp->sampleStdev);
 
         // If the new mean and stdev are NAN, we must exit the loop.
@@ -821,15 +821,15 @@
     if (stats->options & PS_STAT_CLIPPED_MEAN) {
         stats->clippedMean = clippedMean;
-        psTrace(__func__, 6, "The final clipped mean is %f\n", clippedMean);
+        psTrace("psLib.math", 6, "The final clipped mean is %f\n", clippedMean);
     }
     // 8. The last calcuated value of stdev is the clipped stdev.
     if (stats->options & PS_STAT_CLIPPED_STDEV) {
         stats->clippedStdev = clippedStdev;
-        psTrace(__func__, 6, "The final clipped stdev is %f\n", clippedStdev);
+        psTrace("psLib.math", 6, "The final clipped stdev is %f\n", clippedStdev);
     }
 
     psFree(tmpMask);
     psFree(statsTmp);
-    psTrace(__func__, 4, "---- %s(true) end ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s(true) end ----\n", __func__);
     return true;
 }
@@ -884,6 +884,6 @@
                                               )
 {
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
-    psTrace(__func__, 5, "binNum, yVal is (%d, %f)\n", binNum, yVal);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 5, "binNum, yVal is (%d, %f)\n", binNum, yVal);
     if (psTraceGetLevel(__func__) >= 8) {
         PS_VECTOR_PRINT_F32(xVec);
@@ -913,8 +913,8 @@
         y->data.F64[1] = yVec->data.F32[binNum];
         y->data.F64[2] = yVec->data.F32[binNum + 1];
-        psTrace(__func__, 6, "x vec (orig) is (%f %f %f %f)\n", xVec->data.F32[binNum - 1],
+        psTrace("psLib.math", 6, "x vec (orig) is (%f %f %f %f)\n", xVec->data.F32[binNum - 1],
                 xVec->data.F32[binNum], xVec->data.F32[binNum+1], xVec->data.F32[binNum+2]);
-        psTrace(__func__, 6, "x data is (%f %f %f)\n", x->data.F64[0], x->data.F64[1], x->data.F64[2]);
-        psTrace(__func__, 6, "y data is (%f %f %f)\n", y->data.F64[0], y->data.F64[1], y->data.F64[2]);
+        psTrace("psLib.math", 6, "x data is (%f %f %f)\n", x->data.F64[0], x->data.F64[1], x->data.F64[2]);
+        psTrace("psLib.math", 6, "y data is (%f %f %f)\n", y->data.F64[0], y->data.F64[1], y->data.F64[2]);
 
         //
@@ -937,5 +937,5 @@
             psFree(x);
             psFree(y);
-            psTrace(__func__, 5, "---- %s() end ----\n", __func__);
+            psTrace("psLib.math", 5, "---- %s() end ----\n", __func__);
             return NAN;
         }
@@ -949,16 +949,16 @@
             psFree(x);
             psFree(y);
-            psTrace(__func__, 5, "---- %s(NAN) end ----\n", __func__);
+            psTrace("psLib.math", 5, "---- %s(NAN) end ----\n", __func__);
             return NAN;
         }
-        psTrace(__func__, 6, "myPoly->coeff[0] is %f\n", myPoly->coeff[0]);
-        psTrace(__func__, 6, "myPoly->coeff[1] is %f\n", myPoly->coeff[1]);
-        psTrace(__func__, 6, "myPoly->coeff[2] is %f\n", myPoly->coeff[2]);
-        psTrace(__func__, 6, "Fitted y vec is (%f %f %f)\n",
+        psTrace("psLib.math", 6, "myPoly->coeff[0] is %f\n", myPoly->coeff[0]);
+        psTrace("psLib.math", 6, "myPoly->coeff[1] is %f\n", myPoly->coeff[1]);
+        psTrace("psLib.math", 6, "myPoly->coeff[2] is %f\n", myPoly->coeff[2]);
+        psTrace("psLib.math", 6, "Fitted y vec is (%f %f %f)\n",
                 (psF32) psPolynomial1DEval(myPoly, (psF64) x->data.F64[0]),
                 (psF32) psPolynomial1DEval(myPoly, (psF64) x->data.F64[1]),
                 (psF32) psPolynomial1DEval(myPoly, (psF64) x->data.F64[2]));
 
-        psTrace(__func__, 6, "We fit the polynomial, now find x such that f(x) equals %f\n", yVal);
+        psTrace("psLib.math", 6, "We fit the polynomial, now find x such that f(x) equals %f\n", yVal);
         tmpFloat = QuadraticInverse(myPoly->coeff[2], myPoly->coeff[1], myPoly->coeff[0], yVal,
                                     x->data.F64[0], x->data.F64[2]);
@@ -970,5 +970,5 @@
             psFree(x);
             psFree(y);
-            psTrace(__func__, 5, "---- %s(NAN) end ----\n", __func__);
+            psTrace("psLib.math", 5, "---- %s(NAN) end ----\n", __func__);
             return(NAN);
         }
@@ -990,9 +990,9 @@
     }
 
-    psTrace(__func__, 6, "FIT: return %f\n", tmpFloat);
+    psTrace("psLib.math", 6, "FIT: return %f\n", tmpFloat);
     psFree(x);
     psFree(y);
 
-    psTrace(__func__, 5, "---- %s(%f) end ----\n", __func__, tmpFloat);
+    psTrace("psLib.math", 5, "---- %s(%f) end ----\n", __func__, tmpFloat);
     return tmpFloat;
 }
@@ -1006,5 +1006,5 @@
                                   )
 {
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
     PS_ASSERT_VECTOR_NON_NULL(params, NAN);
     PS_ASSERT_VECTOR_SIZE(params, 2, NAN);
@@ -1028,5 +1028,5 @@
 
 
-    psTrace(__func__, 4, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() end ----\n", __func__);
     return gauss;
 }
@@ -1057,5 +1057,5 @@
                               psStats* stats)
 {
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
     if (psTraceGetLevel(__func__) >= 8) {
         PS_VECTOR_PRINT_F32(myVector);
@@ -1085,5 +1085,5 @@
     // Iterate to get the best bin size
     for (int iterate = 1; iterate > 0; iterate++) {
-        psTrace(__func__, 6,
+        psTrace("psLib.math", 6,
                 "-------------------- Iterating on Bin size.  Iteration number %d --------------------\n",
                 iterate);
@@ -1098,12 +1098,12 @@
             psFree(statsMinMax);
             psFree(mask);
-            psTrace(__func__, 4, "---- %s(false) end  ----\n", __func__);
+            psTrace("psLib.math", 4, "---- %s(false) end  ----\n", __func__);
             return false;
         }
-        psTrace(__func__, 6, "Data min/max is (%.2f, %.2f)\n", min, max);
+        psTrace("psLib.math", 6, "Data min/max is (%.2f, %.2f)\n", min, max);
 
         // If all data points have the same value, then we set the appropiate members of stats and return.
         if (fabs(max - min) <= FLT_EPSILON) {
-            psTrace(__func__, 5, "All data points have the same value: %f.\n", min);
+            psTrace("psLib.math", 5, "All data points have the same value: %f.\n", min);
             if (stats->options & PS_STAT_ROBUST_MEDIAN) {
                 stats->robustMedian = min;
@@ -1117,5 +1117,5 @@
             psFree(mask);
 
-            psTrace(__func__, 4, "---- %s(0) end  ----\n", __func__);
+            psTrace("psLib.math", 4, "---- %s(0) end  ----\n", __func__);
             return false;
         }
@@ -1125,10 +1125,10 @@
             // Set initial bin size to the specified value.
             binSize = stats->binsize;
-            psTrace(__func__, 6, "Setting initial robust bin size to %.2f\n", binSize);
+            psTrace("psLib.math", 6, "Setting initial robust bin size to %.2f\n", binSize);
         } else {
             // Determine the bin size of the robust histogram, using the pre-defined number of bins
             binSize = (max - min) / INITIAL_NUM_BINS;
         }
-        psTrace(__func__, 6, "Initial robust bin size is %.2f\n", binSize);
+        psTrace("psLib.math", 6, "Initial robust bin size is %.2f\n", binSize);
 
         // ADD step 0: Construct the histogram with the specified bin size.  NOTE: we can not specify the bin
@@ -1136,6 +1136,6 @@
         // we get here, we know that binSize != 0.0.
         long numBins = (max - min) / binSize; // Number of bins
-        psTrace(__func__, 6, "Numbins is %d\n", numBins);
-        psTrace(__func__, 6, "Creating a robust histogram from data range (%.2f - %.2f)\n", min, max);
+        psTrace("psLib.math", 6, "Numbins is %d\n", numBins);
+        psTrace("psLib.math", 6, "Creating a robust histogram from data range (%.2f - %.2f)\n", min, max);
         // Generate the histogram
         histogram = psHistogramAlloc(min, max, numBins);
@@ -1159,5 +1159,5 @@
         // ADD step 2: Find the bin which contains the 50% data point.
         totalDataPoints = cumulative->nums->data.F32[numBins - 1];
-        psTrace(__func__, 6, "Total data points is %d\n", totalDataPoints);
+        psTrace("psLib.math", 6, "Total data points is %d\n", totalDataPoints);
         long binMedian;
         if (totalDataPoints/2.0 < cumulative->nums->data.F32[0]) {
@@ -1175,9 +1175,9 @@
                 psFree(cumulative);
                 psFree(mask);
-                psTrace(__func__, 4, "---- %s(false) end  ----\n", __func__);
+                psTrace("psLib.math", 4, "---- %s(false) end  ----\n", __func__);
                 return false;
             }
         }
-        psTrace(__func__, 6, "The median bin is %d (%.2f to %.2f)\n", binMedian,
+        psTrace("psLib.math", 6, "The median bin is %d (%.2f to %.2f)\n", binMedian,
                 cumulative->bounds->data.F32[binMedian], cumulative->bounds->data.F32[binMedian+1]);
 
@@ -1192,8 +1192,8 @@
             psFree(cumulative);
             psFree(mask);
-            psTrace(__func__, 4, "---- %s(false) end  ----\n", __func__);
+            psTrace("psLib.math", 4, "---- %s(false) end  ----\n", __func__);
             return false;
         }
-        psTrace(__func__, 6, "Current robust median is %f\n", stats->robustMedian);
+        psTrace("psLib.math", 6, "Current robust median is %f\n", stats->robustMedian);
 
         // ADD step 4: Find the bins which contains the 15.8655% and 84.1345% data points.
@@ -1217,8 +1217,8 @@
             }
         }
-        psTrace(__func__, 6, "The 15.8655%% and 84.1345%% data point bins are (%d, %d).\n",
+        psTrace("psLib.math", 6, "The 15.8655%% and 84.1345%% data point bins are (%d, %d).\n",
                 binLo, binHi);
-        psTrace(__func__, 6, "binLo midpoint is %f\n", PS_BIN_MIDPOINT(cumulative, binLo));
-        psTrace(__func__, 6, "binHi midpoint is %f\n", PS_BIN_MIDPOINT(cumulative, binHi));
+        psTrace("psLib.math", 6, "binLo midpoint is %f\n", PS_BIN_MIDPOINT(cumulative, binLo));
+        psTrace("psLib.math", 6, "binHi midpoint is %f\n", PS_BIN_MIDPOINT(cumulative, binHi));
 
         if ((binLo < 0) || (binHi < 0)) {
@@ -1228,5 +1228,5 @@
             psFree(cumulative);
             psFree(mask);
-            psTrace(__func__, 4, "---- %s(false) end  ----\n", __func__);
+            psTrace("psLib.math", 4, "---- %s(false) end  ----\n", __func__);
             return false;
         }
@@ -1244,11 +1244,11 @@
         float binHiF32 = fitQuadraticSearchForYThenReturnX(cumulative->bounds, cumulative->nums, binHi,
                          totalDataPoints * 0.841345f);
-        psTrace(__func__, 6, "The exact 15.8655%% and 84.1345%% data point positions are: (%f, %f)\n",
+        psTrace("psLib.math", 6, "The exact 15.8655%% and 84.1345%% data point positions are: (%f, %f)\n",
                 binLoF32, binHiF32);
         #else
         // This code basically interpolates to find the positions exactly.
-        psTrace(__func__, 6, "binLo is %d.  Nums at that bin and the next are (%.2f, %.2f)\n",
+        psTrace("psLib.math", 6, "binLo is %d.  Nums at that bin and the next are (%.2f, %.2f)\n",
                 binLo, cumulative->nums->data.F32[binLo], cumulative->nums->data.F32[binLo+1]);
-        psTrace(__func__, 6, "binHi is %d.  Nums at that bin and the next are (%.2f, %.2f)\n",
+        psTrace("psLib.math", 6, "binHi is %d.  Nums at that bin and the next are (%.2f, %.2f)\n",
                 binHi, cumulative->nums->data.F32[binHi], cumulative->nums->data.F32[binHi+1]);
 
@@ -1266,5 +1266,5 @@
         float base = cumulative->bounds->data.F32[binLo];
         float binLoF32 = base + (deltaBounds / deltaNums) * percentNums; // Value for the 15.8655% mark
-        psTrace(__func__, 6,
+        psTrace("psLib.math", 6,
                 "(base, deltaBounds, deltaNums, prevPixels, percentNums) is (%.2f %.2f %.2f %.2f %.2f)\n",
                 base, deltaBounds, deltaNums, prevPixels, percentNums);
@@ -1281,8 +1281,8 @@
         base = cumulative->bounds->data.F32[binHi];
         float binHiF32 = base + (deltaBounds / deltaNums) * percentNums; // Value for the 84.1345% mark
-        psTrace(__func__, 6,
+        psTrace("psLib.math", 6,
                 "(base, deltaBounds, deltaNums, prevPixels, percentNums) is (%.2f %.2f %.2f %.2f %.2f)\n",
                 base, deltaBounds, deltaNums, prevPixels, percentNums);
-        psTrace(__func__, 6,
+        psTrace("psLib.math", 6,
                 "The exact 15.8655 and 84.1345 percent data point positions are: (%f, %f)\n",
                 binLoF32, binHiF32);
@@ -1291,5 +1291,5 @@
         // ADD step 5: Determine SIGMA as 1/2 of the distance between these positions.
         sigma = (binHiF32 - binLoF32) / 2.0;
-        psTrace(__func__, 6, "The current sigma is %f.\n", sigma);
+        psTrace("psLib.math", 6, "The current sigma is %f.\n", sigma);
         stats->robustStdev = sigma;
 
@@ -1297,18 +1297,18 @@
         // than 25 bins from the median, recalculate the bin size, and perform the algorithm again.
         if (sigma < (2 * binSize)) {
-            psTrace(__func__, 6, "*************: Do another iteration (%f %f).\n", sigma, binSize);
+            psTrace("psLib.math", 6, "*************: Do another iteration (%f %f).\n", sigma, binSize);
             long maskLo = PS_MAX(0, (binMedian - 25)); // Low index for masking region
             long maskHi = PS_MIN(histogram->bounds->n - 1, (binMedian + 25)); // High index for masking
             psF32 medianLo = histogram->bounds->data.F32[maskLo]; // Value at low index
             psF32 medianHi = histogram->bounds->data.F32[maskHi]; // Value at high index
-            psTrace(__func__, 6, "Masking data more than 25 bins from the median\n");
-            psTrace(__func__, 6,
+            psTrace("psLib.math", 6, "Masking data more than 25 bins from the median\n");
+            psTrace("psLib.math", 6,
                     "The median is at bin number %d.  We mask bins outside the bin range (%d:%d)\n",
                     binMedian, maskLo, maskHi);
-            psTrace(__func__, 6, "Masking data outside (%f %f)\n", medianLo, medianHi);
+            psTrace("psLib.math", 6, "Masking data outside (%f %f)\n", medianLo, medianHi);
             for (long i = 0 ; i < myVector->n ; i++) {
                 if ((myVector->data.F32[i] < medianLo) || (myVector->data.F32[i] > medianHi)) {
                     mask->data.U8[i] = 0xff;
-                    psTrace(__func__, 6, "Masking element %d is %f\n", i, myVector->data.F32[i]);
+                    psTrace("psLib.math", 6, "Masking element %d is %f\n", i, myVector->data.F32[i]);
                 }
             }
@@ -1318,5 +1318,5 @@
         } else {
             // We've got the bin size correct now
-            psTrace(__func__, 6, "*************: No more iteration.  sigma is %f\n", sigma);
+            psTrace("psLib.math", 6, "*************: No more iteration.  sigma is %f\n", sigma);
             iterate = -1;
         }
@@ -1347,8 +1347,8 @@
         psFree(cumulative);
         psFree(mask);
-        psTrace(__func__, 4, "---- %s(false) end  ----\n", __func__);
+        psTrace("psLib.math", 4, "---- %s(false) end  ----\n", __func__);
         return false;
     }
-    psTrace(__func__, 6, "The 25-percent and 75-precent data point bins are (%d, %d).\n", binLo25, binHi25);
+    psTrace("psLib.math", 6, "The 25-percent and 75-precent data point bins are (%d, %d).\n", binLo25, binHi25);
 
     // ADD step 8: Interpolate to find these two positions exactly: these are the upper and lower quartile
@@ -1365,5 +1365,5 @@
         psFree(statsMinMax);
         psFree(mask);
-        psTrace(__func__, 4, "---- %s(1) end  ----\n", __func__);
+        psTrace("psLib.math", 4, "---- %s(1) end  ----\n", __func__);
         return false;
     }
@@ -1371,5 +1371,5 @@
     stats->robustLQ = binLo25F32;
     stats->robustUQ = binHi25F32;
-    psTrace(__func__, 6, "The 25 and 75 percent data point exact positions are (%f, %f).\n",
+    psTrace("psLib.math", 6, "The 25 and 75 percent data point exact positions are (%f, %f).\n",
             binLo25F32, binHi25F32);
     long N50 = 0;
@@ -1381,5 +1381,5 @@
     }
     stats->robustN50 = N50;
-    psTrace(__func__, 6, "The robustN50 is %d.\n", N50);
+    psTrace("psLib.math", 6, "The robustN50 is %d.\n", N50);
 
 
@@ -1405,5 +1405,5 @@
             psFree(statsMinMax);
             psFree(mask);
-            psTrace(__func__, 4, "---- %s(false) end  ----\n", __func__);
+            psTrace("psLib.math", 4, "---- %s(false) end  ----\n", __func__);
             return false;
         }
@@ -1411,7 +1411,7 @@
         // Calculate the number of bins.
         long numBins = (max - min) / newBinSize;
-        psTrace(__func__, 6, "The new min/max values are (%f, %f).\n", min, max);
-        psTrace(__func__, 6, "The new bin size is %f.\n", newBinSize);
-        psTrace(__func__, 6, "The numBins is %d\n", numBins);
+        psTrace("psLib.math", 6, "The new min/max values are (%f, %f).\n", min, max);
+        psTrace("psLib.math", 6, "The new bin size is %f.\n", newBinSize);
+        psTrace("psLib.math", 6, "The numBins is %d\n", numBins);
 
         psHistogram *histogram = psHistogramAlloc(min, max, numBins); // A new histogram (without outliers)
@@ -1448,5 +1448,5 @@
             psFree(histogram);
             psFree(mask);
-            psTrace(__func__, 4, "---- %s(false) end  ----\n", __func__);
+            psTrace("psLib.math", 4, "---- %s(false) end  ----\n", __func__);
             return false;
         }
@@ -1460,5 +1460,5 @@
             }
         }
-        psTrace(__func__, 6, "The peak bin is %d, with %f data.n", binNum, binMaxNums);
+        psTrace("psLib.math", 6, "The peak bin is %d, with %f data.n", binNum, binMaxNums);
 
         // Fit a Gaussian to the bins in the range 20 sigma of the robust histogram median.
@@ -1480,5 +1480,5 @@
             psFree(histogram);
             psFree(mask);
-            psTrace(__func__, 4, "---- %s(false) end  ----\n", __func__);
+            psTrace("psLib.math", 4, "---- %s(false) end  ----\n", __func__);
             return false;
         }
@@ -1511,5 +1511,5 @@
             psFree(histogram);
             psFree(statsMinMax);
-            psTrace(__func__, 4, "---- %s(false) end  ----\n", __func__);
+            psTrace("psLib.math", 4, "---- %s(false) end  ----\n", __func__);
             return false;
         }
@@ -1537,5 +1537,5 @@
             psFree(params);
             psFree(mask);
-            psTrace(__func__, 4, "---- %s(false) end  ----\n", __func__);
+            psTrace("psLib.math", 4, "---- %s(false) end  ----\n", __func__);
             return false;
         }
@@ -1546,10 +1546,10 @@
         // The fitted mean is the Gaussian mean.
         stats->fittedMean = params->data.F32[0];
-        psTrace(__func__, 6, "The fitted mean is %f.\n", params->data.F32[0]);
+        psTrace("psLib.math", 6, "The fitted mean is %f.\n", params->data.F32[0]);
 
         // The fitted standard deviation, SIGMA_r is determined by subtracting the smoothing scale in
         // quadrature: SIGMA_r^2 = SIGMA^2 - sigma_s^2
         stats->fittedStdev = sqrt(PS_SQR(params->data.F32[1]) - PS_SQR(newBinSize));
-        psTrace(__func__, 6, "The fitted stdev is %f.\n", stats->fittedStdev);
+        psTrace("psLib.math", 6, "The fitted stdev is %f.\n", stats->fittedStdev);
 
         // Clean up after fitting
@@ -1564,5 +1564,5 @@
     psFree(mask);
 
-    psTrace(__func__, 4, "---- %s(0) end  ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s(0) end  ----\n", __func__);
     return true;
 }
@@ -1587,5 +1587,5 @@
 psStats* psStatsAlloc(psStatsOptions options)
 {
-    psTrace(__func__, 3,"---- %s() begin  ----\n", __func__);
+    psTrace("psLib.math", 3,"---- %s() begin  ----\n", __func__);
     psStats* newStruct = NULL;
 
@@ -1616,5 +1616,5 @@
     newStruct->options = options;
 
-    psTrace(__func__, 3, "---- %s() end  ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() end  ----\n", __func__);
     return (newStruct);
 }
@@ -1645,6 +1645,6 @@
 psHistogram* psHistogramAlloc(float lower, float upper, int n)
 {
-    psTrace(__func__, 3, "---- %s() begin  ----\n", __func__);
-    psTrace(__func__, 5, "(lower, upper, n) is (%f, %f, %d)\n", lower, upper, n);
+    psTrace("psLib.math", 3, "---- %s() begin  ----\n", __func__);
+    psTrace("psLib.math", 5, "(lower, upper, n) is (%f, %f, %d)\n", lower, upper, n);
     PS_ASSERT_INT_POSITIVE(n, NULL);
     PS_ASSERT_FLOAT_LARGER_THAN_OR_EQUAL(upper, lower, NULL);
@@ -1678,5 +1678,5 @@
     newHist->uniform = true;
 
-    psTrace(__func__, 3, "---- %s() end  ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() end  ----\n", __func__);
     return newHist;
 }
@@ -1693,5 +1693,5 @@
 psHistogram* psHistogramAllocGeneric(const psVector* bounds)
 {
-    psTrace(__func__, 3, "---- %s() begin  ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() begin  ----\n", __func__);
     PS_ASSERT_VECTOR_NON_NULL(bounds, NULL);
     PS_ASSERT_VECTOR_TYPE(bounds, PS_TYPE_F32, NULL);
@@ -1721,5 +1721,5 @@
     newHist->uniform = false;
 
-    psTrace(__func__, 3, "---- %s() end  ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() end  ----\n", __func__);
     return (newHist);
 }
@@ -1757,5 +1757,5 @@
                                )
 {
-    psTrace(__func__, 3, "---- %s() begin  ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() begin  ----\n", __func__);
     PS_ASSERT_PTR_NON_NULL(out, false);
     PS_ASSERT_PTR_NON_NULL(out->bounds, false);
@@ -1794,5 +1794,5 @@
     if (boxcarLeftBinNum == boxcarRightBinNum) {
         out->nums->data.F32[binNum] += 1.0;
-        psTrace(__func__, 3, "---- %s(true) end  ----\n", __func__);
+        psTrace("psLib.math", 3, "---- %s(true) end  ----\n", __func__);
         return true;
     }
@@ -1813,5 +1813,5 @@
         (boxcarRight - out->bounds->data.F32[boxcarRightBinNum]) / boxcarWidth;
 
-    psTrace(__func__, 3, "---- %s(true) end  ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s(true) end  ----\n", __func__);
     return true;
 }
@@ -1838,5 +1838,5 @@
                                psMaskType maskVal)
 {
-    psTrace(__func__, 3, "---- %s() begin  ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() begin  ----\n", __func__);
     PS_ASSERT_PTR_NON_NULL(out, NULL);
     PS_ASSERT_VECTOR_NON_NULL(out->bounds, NULL);
@@ -1933,5 +1933,5 @@
     psFree(errorsF32);
 
-    psTrace(__func__, 3, "---- %s() end  ----\n", __func__);
+    psTrace("psLib.math", 3, "---- %s() end  ----\n", __func__);
     return (out);
 }
@@ -1959,5 +1959,5 @@
     psMaskType maskVal)
 {
-    psTrace(__func__, 3,"---- %s() begin  ----\n", __func__);
+    psTrace("psLib.math", 3,"---- %s() begin  ----\n", __func__);
     PS_ASSERT_PTR_NON_NULL(stats, NULL);
     PS_ASSERT_VECTOR_NON_NULL(in, NULL);
@@ -2039,5 +2039,5 @@
             psFree(inF32);
             psFree(errorsF32);
-            psTrace(__func__, 3,"---- %s(NULL) end  ----\n", __func__);
+            psTrace("psLib.math", 3,"---- %s(NULL) end  ----\n", __func__);
             return(NULL);
         }
@@ -2063,5 +2063,5 @@
     psFree(errorsF32);
     psFree(maskU8);
-    psTrace(__func__, 3,"---- %s() end  ----\n", __func__);
+    psTrace("psLib.math", 3,"---- %s() end  ----\n", __func__);
     return (stats);
 }
Index: /trunk/psLib/src/sys/psLogMsg.c
===================================================================
--- /trunk/psLib/src/sys/psLogMsg.c	(revision 8244)
+++ /trunk/psLib/src/sys/psLogMsg.c	(revision 8245)
@@ -11,6 +11,6 @@
  *  @author GLG, MHPCC
  *
- *  @version $Revision: 1.60 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-08-08 23:32:23 $
+ *  @version $Revision: 1.61 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-08-09 02:26:44 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -172,5 +172,5 @@
     // XXX: If one must at least log error messages, why don't we set logMsg = true here?
     if (!logMsg) {
-        psTrace("utils.logMsg", 1, "You must at least log error messages (You chose \"%s\")", format);
+        psTrace("psLib.sys", 1, "You must at least log error messages (You chose \"%s\")", format);
 
     }
@@ -293,5 +293,5 @@
 
     default:
-        psTrace("utils.logMsg", 2, "Invalid logMsg level: %d (%s)\n", level, format);
+        psTrace("psLib.sys", 2, "Invalid logMsg level: %d (%s)\n", level, format);
         level = (level < 0) ? 0 : 9;
         clevel = level + '0';
Index: /trunk/psLib/src/sys/psTrace.c
===================================================================
--- /trunk/psLib/src/sys/psTrace.c	(revision 8244)
+++ /trunk/psLib/src/sys/psTrace.c	(revision 8245)
@@ -9,6 +9,6 @@
  *  @author GLG, MHPCC
  *
- *  @version $Revision: 1.66 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-08-09 02:01:02 $
+ *  @version $Revision: 1.67 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-08-09 02:26:44 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -525,5 +525,5 @@
         clevel = level + '0';
     } else {
-        psTrace("utils.logMsg", 2, "Invalid logMsg level: %d (%s)\n", level, format);
+        psTrace("psLib.sys", 2, "Invalid logMsg level: %d (%s)\n", level, format);
         level = (level < 0) ? 0 : 9;
         clevel = level + '0';
@@ -721,5 +721,5 @@
     // XXX: If one must at least log error messages, why don't we set logMsg = true here?
     if (!traceMsg) {
-        psTrace("utils.traceMsg", 1,
+        psTrace("psLib.sys", 1,
                 "You must at least trace error messages (You chose \"%s\")", format);
 
Index: /trunk/psLib/src/types/psArguments.c
===================================================================
--- /trunk/psLib/src/types/psArguments.c	(revision 8244)
+++ /trunk/psLib/src/types/psArguments.c	(revision 8245)
@@ -7,6 +7,6 @@
  *  @author David Robbins, MHPCC
  *
- *  @version $Revision: 1.9 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-08-08 23:32:23 $
+ *  @version $Revision: 1.10 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-08-09 02:26:44 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -156,5 +156,5 @@
 
     for (int i = 1; i < *argc; i++) {
-        psTrace(__func__, 7, "Looking at %s\n", argv[i]);
+        psTrace("psLib.types", 7, "Looking at %s\n", argv[i]);
         psMetadataItem *argItem = psMetadataLookup(arguments, argv[i]);
         if (argItem) {
Index: /trunk/psLib/src/types/psHash.c
===================================================================
--- /trunk/psLib/src/types/psHash.c	(revision 8244)
+++ /trunk/psLib/src/types/psHash.c	(revision 8245)
@@ -12,6 +12,6 @@
 *  @author GLG, MHPCC
 *
-*  @version $Revision: 1.27 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2006-08-08 23:32:23 $
+*  @version $Revision: 1.28 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2006-08-09 02:26:44 $
 *
 *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -148,5 +148,5 @@
     table->n = nalloc;
 
-    psTrace("utils.hash", 1, "Creating %d-element hash table\n", nalloc);
+    psTrace("psLib.types", 1, "Creating %d-element hash table\n", nalloc);
 
     // Initialize all buckets to NULL.
@@ -321,5 +321,5 @@
                 // We have found this key in the hash table.
 
-                psTrace("utils.hash.insert", 3, "Replacing data for %s\n", key);
+                psTrace("psLib.types", 3, "Replacing data for %s\n", key);
 
                 // NOTE: I have changed this behavior from the originally
Index: /trunk/psLib/src/types/psMetadata.c
===================================================================
--- /trunk/psLib/src/types/psMetadata.c	(revision 8244)
+++ /trunk/psLib/src/types/psMetadata.c	(revision 8245)
@@ -12,6 +12,6 @@
  *  @author Ross Harman, MHPCC
  *
- *  @version $Revision: 1.121 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-08-08 23:32:23 $
+ *  @version $Revision: 1.122 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-08-09 02:26:44 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -445,8 +445,8 @@
         unsigned int flag = PS_META_REPLACE; // Flag to indicate MULTI; otherwise, replace
         if (multiCheckItem->type == PS_DATA_METADATA_MULTI) {
-            psTrace(__func__, 10, "MULTI: %s (%s)\n", inItem->name, inItem->comment);
+            psTrace("psLib.types", 10, "MULTI: %s (%s)\n", inItem->name, inItem->comment);
             flag = PS_META_DUPLICATE_OK;
         }
-        psTrace(__func__, 5, "Copying %s (%s)...\n", inItem->name, inItem->comment);
+        psTrace("psLib.types", 5, "Copying %s (%s)...\n", inItem->name, inItem->comment);
 
         // Copy the item and add it on
Index: /trunk/psLib/src/types/psMetadataItemCompare.c
===================================================================
--- /trunk/psLib/src/types/psMetadataItemCompare.c	(revision 8244)
+++ /trunk/psLib/src/types/psMetadataItemCompare.c	(revision 8245)
@@ -67,5 +67,5 @@
             return false;
         }
-        psTrace(__func__, 10, "Comparing '%s' with '%s'\n", compare->data.V, template->
+        psTrace("psLib.types", 10, "Comparing '%s' with '%s'\n", compare->data.V, template->
                 data.V);
         return (strcasecmp(compare->data.V, template->

Index: /trunk/psLib/src/math/psMathUtils.c
===================================================================
--- /trunk/psLib/src/math/psMathUtils.c	(revision 8244)
+++ /trunk/psLib/src/math/psMathUtils.c	(revision 8245)
@@ -3,6 +3,6 @@
  *  This file contains standard math routines.
  *
- *  @version $Revision: 1.4 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-08-08 23:32:23 $
+ *  @version $Revision: 1.5 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-08-09 02:26:44 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -58,6 +58,6 @@
     long max; \
     long mid; \
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__); \
-    /* psTrace(__func__, 6, "Determining the bin for: %f\n", x); */\
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__); \
+    /* psTrace("psLib.math", 6, "Determining the bin for: %f\n", x); */\
     if (value < bounds[0]) { \
         psLogMsg(__func__, PS_LOG_WARN, \
@@ -79,5 +79,5 @@
         \
         if (value == bounds[mid]) { \
-            psTrace(__func__, 4, "---- %s(%d) end (1) ----\n", __func__, mid); \
+            psTrace("psLib.math", 4, "---- %s(%d) end (1) ----\n", __func__, mid); \
             return(mid); \
         } else if (value < bounds[mid]) { \
@@ -88,5 +88,5 @@
         mid = ((max+1)+min)/2; \
     } \
-    psTrace(__func__, 4, "---- %s(%d) end (2) ----\n", __func__, min); \
+    psTrace("psLib.math", 4, "---- %s(%d) end (2) ----\n", __func__, min); \
     return(min); \
 }
@@ -135,5 +135,5 @@
 #define VECTOR_INTERPOLATE_CASE(TYPE) \
 case PS_TYPE_##TYPE: { \
-    psTrace(__func__, 4, "---- %s() begin %u-order.) (%d data points) ----\n", __func__, order, order+1); \
+    psTrace("psLib.math", 4, "---- %s() begin %u-order.) (%d data points) ----\n", __func__, order, order+1); \
     if (x->data.TYPE < domain->data.TYPE[0]) { \
         psLogMsg(__func__, PS_LOG_WARN, "WARNING: x is outside the domain of input data.\n"); \
@@ -173,5 +173,5 @@
     out->data.TYPE = p->data.TYPE[origin]; \
     psFree(p); \
-    psTrace(__func__, 4, "---- %s(....) end ----\n", __func__); \
+    psTrace("psLib.math", 4, "---- %s(....) end ----\n", __func__); \
     return(out); \
 }
@@ -192,5 +192,5 @@
     const psScalar *x)
 {
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
     PS_ASSERT_VECTOR_NON_NULL(domain, NULL);
     PS_ASSERT_VECTOR_NON_NULL(range, NULL);
@@ -275,5 +275,5 @@
 {
     PS_ASSERT_VECTOR_NON_NULL(myData, false);
-    psTrace(__func__, 4, "---- %s() begin ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() begin ----\n", __func__);
 
     switch (myData->type.type) {
@@ -295,5 +295,5 @@
         }
     }
-    psTrace(__func__, 4, "---- %s() end ----\n", __func__);
+    psTrace("psLib.math", 4, "---- %s() end ----\n", __func__);
     return true;
 }